(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    203980,       3416]
NotebookOptionsPosition[    196725,       3223]
NotebookOutlinePosition[    201714,       3344]
CellTagsIndexPosition[    201671,       3341]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Solving the Knights Tour on and off the chess board", "Title",
 CellID->348904812],

Cell["June 3, 2014", "Date",
 CellID->1412818974],

Cell["\<\
Jon McLoone,  International Business & Strategic Development \
\>", "Author",
 CellID->521811139],

Cell[TextData[{
 "I first came across the ",
 ButtonBox["Knights Tour",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/KnightGraph.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/KnightGraph.html"],
 " problem in the early \[OpenCurlyQuote]80s when a performer on the BBC\
\[CloseCurlyQuote]s Paul Daniels Magic Show, demonstrated that he could find \
a route for a knight to visit every square on the chess board, once and only \
once, from a random start-point chosen by the audience. Of course the act was \
mostly showmanship, but it was a few years before i realized that he had \
simply memorized a closed (or re-entrant) tour, (one that ended back where he \
started), so whatever the audience chose he could continue the same sequence \
from that point.\n\nIn college, some years later, I spent some hours trying, \
and failing, to find any Knights Tour using pencil and paper in various \
systematic and haphazard ways. And for no particular reason, this memory came \
to me while I was driving to work today, along with the realization that the \
problem reduces down to finding a ",
 ButtonBox["Hamiltonian Cycle",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/HamiltonianCycle.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/HamiltonianCycle.html"],
 " of the graph of possible knight moves. Something that is easy to do in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". Here is how..."
}], "Text"],

Cell["=============break=================", "Text"],

Cell[TextData[{
 "The first thing that we have to do is to construct the graph of knights \
moves. In the open a knight can move to eight possible squares, but as few as \
two in the corners. But if you ignore that and remember that when you were \
taught chess, you were probably told that it could move along two and across \
one, or visa-versa. This gives the knight the property that it always moves a \
",
 ButtonBox["EuclideanDistance",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/mathematica/ref/EuclideanDistance.html"]\
, None},
  ButtonNote->
   "http://reference.wolfram.com/mathematica/ref/EuclideanDistance.html"],
 " of ",
 Cell[BoxData[
  FormBox[
   SqrtBox["5"], TraditionalForm]]],
 ". We can use this test to construct the edges of our graph from the list of \
all possible pairs of positions. "
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"knightGraph", "[", "pts_", "]"}], ":=", 
   RowBox[{"Graph", "[", 
    RowBox[{"Union", "[", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"EuclideanDistance", "[", 
            RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
           SqrtBox["5"]}], ",", 
          RowBox[{"Sort", "[", 
           RowBox[{"x", "\[UndirectedEdge]", "y"}], "]"}], ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "pts"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", "pts"}], "}"}]}], "]"}], "]"}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellLabel->"In[1]:="],

Cell["\<\
Sorting removes unhelpful multiple edges which just slow the computation \
down. Ignoring chess conventions I take x and y to both take values 1-8 \
(rather than x being from A to H)\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"standardBoard", "=", 
  RowBox[{"knightGraph", "[", 
   RowBox[{"Tuples", "[", 
    RowBox[{
     RowBox[{"Range", "[", "8", "]"}], ",", "2"}], "]"}], "]"}]}]], "Input",
 CellLabel->"In[2]:="],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{{1, 1}, {2, 3}, {3, 2}, {1, 2}, {2, 4}, {3, 1}, {3, 3}, {1, 3}, {
      2, 1}, {2, 5}, {3, 4}, {1, 4}, {2, 2}, {2, 6}, {3, 5}, {1, 5}, {2, 7}, {
      3, 6}, {1, 6}, {2, 8}, {3, 7}, {1, 7}, {3, 8}, {1, 8}, {4, 2}, {4, 1}, {
      4, 3}, {4, 4}, {4, 5}, {4, 6}, {4, 7}, {4, 8}, {5, 2}, {5, 1}, {5, 3}, {
      5, 4}, {5, 5}, {5, 6}, {5, 7}, {5, 8}, {6, 2}, {6, 1}, {6, 3}, {6, 4}, {
      6, 5}, {6, 6}, {6, 7}, {6, 8}, {7, 2}, {7, 1}, {7, 3}, {7, 4}, {7, 5}, {
      7, 6}, {7, 7}, {7, 8}, {8, 2}, {8, 1}, {8, 3}, {8, 4}, {8, 5}, {8, 6}, {
      8, 7}, {8, 8}}, {Null, CompressedData["
1:eJwVxed5gkAAAFAFKdKOIiK93FGPKk0F1BkyggtkrYyZ5Mf7Xvj5/voQu93u
58//e2JPHqgDfWDYI8uxJMsLoiAJjABkQlZkXlY1SjtpQNPP3Fk9Gxfpoh+Z
oynyoiXaBE0AwiQciqRUyqZcjuF0zuE8iZcMyZV8BSieEpzUk0/bdEg6ZERC
xmJcJmQQb/IeD/kY2MAHCCSqowZqrKa6qyd6ZnhGakErN5FZmNiO7NjO7dIJ
ncTBTuVCN3VLt/aQl3mV1/ixX/ttkARNhKMuLMNr2MMCVrCDA8pRjXo0xjhu
4iGekjJpkzGZ0yqd0ltWZ3PRF/d8yB/5gq94xHe8ll05lUu5VX01V2v1rIf6
Vm/1qxmbZ/Nup/Z1Xbq1f/TbcB+e4zK+pnV6z9vt+Qv66Cv6
       "]}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$15", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$16", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$25", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$28", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$28", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$34", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$35", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$18", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$19", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$27", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$29", Automatic, Center]}, {
          DynamicLocation["VertexID$6", Automatic, Center], 
          DynamicLocation["VertexID$27", Automatic, Center]}, {
          DynamicLocation["VertexID$6", Automatic, Center], 
          DynamicLocation["VertexID$33", Automatic, Center]}, {
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}, {
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$10", Automatic, Center]}, {
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$12", Automatic, Center]}, {
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$26", Automatic, Center]}, {
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$29", Automatic, Center]}, {
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$33", Automatic, Center]}, {
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$36", Automatic, Center]}, {
          DynamicLocation["VertexID$8", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}, {
          DynamicLocation["VertexID$8", Automatic, Center], 
          DynamicLocation["VertexID$10", Automatic, Center]}, {
          DynamicLocation["VertexID$8", Automatic, Center], 
          DynamicLocation["VertexID$11", Automatic, Center]}, {
          DynamicLocation["VertexID$9", Automatic, Center], 
          DynamicLocation["VertexID$25", Automatic, Center]}, {
          DynamicLocation["VertexID$10", Automatic, Center], 
          DynamicLocation["VertexID$21", Automatic, Center]}, {
          DynamicLocation["VertexID$10", Automatic, Center], 
          DynamicLocation["VertexID$22", Automatic, Center]}, {
          DynamicLocation["VertexID$10", Automatic, Center], 
          DynamicLocation["VertexID$28", Automatic, Center]}, {
          DynamicLocation["VertexID$10", Automatic, Center], 
          DynamicLocation["VertexID$30", Automatic, Center]}, {
          DynamicLocation["VertexID$11", Automatic, Center], 
          DynamicLocation["VertexID$13", Automatic, Center]}, {
          DynamicLocation["VertexID$11", Automatic, Center], 
          DynamicLocation["VertexID$14", Automatic, Center]}, {
          DynamicLocation["VertexID$11", Automatic, Center], 
          DynamicLocation["VertexID$16", Automatic, Center]}, {
          DynamicLocation["VertexID$11", Automatic, Center], 
          DynamicLocation["VertexID$25", Automatic, Center]}, {
          DynamicLocation["VertexID$11", Automatic, Center], 
          DynamicLocation["VertexID$30", Automatic, Center]}, {
          DynamicLocation["VertexID$11", Automatic, Center], 
          DynamicLocation["VertexID$35", Automatic, Center]}, {
          DynamicLocation["VertexID$11", Automatic, Center], 
          DynamicLocation["VertexID$37", Automatic, Center]}, {
          DynamicLocation["VertexID$12", Automatic, Center], 
          DynamicLocation["VertexID$13", Automatic, Center]}, {
          DynamicLocation["VertexID$12", Automatic, Center], 
          DynamicLocation["VertexID$14", Automatic, Center]}, {
          DynamicLocation["VertexID$12", Automatic, Center], 
          DynamicLocation["VertexID$15", Automatic, Center]}, {
          DynamicLocation["VertexID$13", Automatic, Center], 
          DynamicLocation["VertexID$26", Automatic, Center]}, {
          DynamicLocation["VertexID$13", Automatic, Center], 
          DynamicLocation["VertexID$27", Automatic, Center]}, {
          DynamicLocation["VertexID$14", Automatic, Center], 
          DynamicLocation["VertexID$23", Automatic, Center]}, {
          DynamicLocation["VertexID$14", Automatic, Center], 
          DynamicLocation["VertexID$24", Automatic, Center]}, {
          DynamicLocation["VertexID$14", Automatic, Center], 
          DynamicLocation["VertexID$29", Automatic, Center]}, {
          DynamicLocation["VertexID$14", Automatic, Center], 
          DynamicLocation["VertexID$31", Automatic, Center]}, {
          DynamicLocation["VertexID$15", Automatic, Center], 
          DynamicLocation["VertexID$17", Automatic, Center]}, {
          DynamicLocation["VertexID$15", Automatic, Center], 
          DynamicLocation["VertexID$19", Automatic, Center]}, {
          DynamicLocation["VertexID$15", Automatic, Center], 
          DynamicLocation["VertexID$27", Automatic, Center]}, {
          DynamicLocation["VertexID$15", Automatic, Center], 
          DynamicLocation["VertexID$31", Automatic, Center]}, {
          DynamicLocation["VertexID$15", Automatic, Center], 
          DynamicLocation["VertexID$36", Automatic, Center]}, {
          DynamicLocation["VertexID$15", Automatic, Center], 
          DynamicLocation["VertexID$38", Automatic, Center]}, {
          DynamicLocation["VertexID$16", Automatic, Center], 
          DynamicLocation["VertexID$17", Automatic, Center]}, {
          DynamicLocation["VertexID$16", Automatic, Center], 
          DynamicLocation["VertexID$18", Automatic, Center]}, {
          DynamicLocation["VertexID$17", Automatic, Center], 
          DynamicLocation["VertexID$30", Automatic, Center]}, {
          DynamicLocation["VertexID$17", Automatic, Center], 
          DynamicLocation["VertexID$32", Automatic, Center]}, {
          DynamicLocation["VertexID$18", Automatic, Center], 
          DynamicLocation["VertexID$20", Automatic, Center]}, {
          DynamicLocation["VertexID$18", Automatic, Center], 
          DynamicLocation["VertexID$22", Automatic, Center]}, {
          DynamicLocation["VertexID$18", Automatic, Center], 
          DynamicLocation["VertexID$28", Automatic, Center]}, {
          DynamicLocation["VertexID$18", Automatic, Center], 
          DynamicLocation["VertexID$32", Automatic, Center]}, {
          DynamicLocation["VertexID$18", Automatic, Center], 
          DynamicLocation["VertexID$37", Automatic, Center]}, {
          DynamicLocation["VertexID$18", Automatic, Center], 
          DynamicLocation["VertexID$39", Automatic, Center]}, {
          DynamicLocation["VertexID$19", Automatic, Center], 
          DynamicLocation["VertexID$20", Automatic, Center]}, {
          DynamicLocation["VertexID$19", Automatic, Center], 
          DynamicLocation["VertexID$21", Automatic, Center]}, {
          DynamicLocation["VertexID$20", Automatic, Center], 
          DynamicLocation["VertexID$31", Automatic, Center]}, {
          DynamicLocation["VertexID$21", Automatic, Center], 
          DynamicLocation["VertexID$24", Automatic, Center]}, {
          DynamicLocation["VertexID$21", Automatic, Center], 
          DynamicLocation["VertexID$29", Automatic, Center]}, {
          DynamicLocation["VertexID$21", Automatic, Center], 
          DynamicLocation["VertexID$38", Automatic, Center]}, {
          DynamicLocation["VertexID$21", Automatic, Center], 
          DynamicLocation["VertexID$40", Automatic, Center]}, {
          DynamicLocation["VertexID$22", Automatic, Center], 
          DynamicLocation["VertexID$23", Automatic, Center]}, {
          DynamicLocation["VertexID$23", Automatic, Center], 
          DynamicLocation["VertexID$30", Automatic, Center]}, {
          DynamicLocation["VertexID$23", Automatic, Center], 
          DynamicLocation["VertexID$39", Automatic, Center]}, {
          DynamicLocation["VertexID$25", Automatic, Center], 
          DynamicLocation["VertexID$36", Automatic, Center]}, {
          DynamicLocation["VertexID$25", Automatic, Center], 
          DynamicLocation["VertexID$42", Automatic, Center]}, {
          DynamicLocation["VertexID$25", Automatic, Center], 
          DynamicLocation["VertexID$43", Automatic, Center]}, {
          DynamicLocation["VertexID$26", Automatic, Center], 
          DynamicLocation["VertexID$35", Automatic, Center]}, {
          DynamicLocation["VertexID$26", Automatic, Center], 
          DynamicLocation["VertexID$41", Automatic, Center]}, {
          DynamicLocation["VertexID$27", Automatic, Center], 
          DynamicLocation["VertexID$34", Automatic, Center]}, {
          DynamicLocation["VertexID$27", Automatic, Center], 
          DynamicLocation["VertexID$37", Automatic, Center]}, {
          DynamicLocation["VertexID$27", Automatic, Center], 
          DynamicLocation["VertexID$41", Automatic, Center]}, {
          DynamicLocation["VertexID$27", Automatic, Center], 
          DynamicLocation["VertexID$44", Automatic, Center]}, {
          DynamicLocation["VertexID$28", Automatic, Center], 
          DynamicLocation["VertexID$33", Automatic, Center]}, {
          DynamicLocation["VertexID$28", Automatic, Center], 
          DynamicLocation["VertexID$38", Automatic, Center]}, {
          DynamicLocation["VertexID$28", Automatic, Center], 
          DynamicLocation["VertexID$43", Automatic, Center]}, {
          DynamicLocation["VertexID$28", Automatic, Center], 
          DynamicLocation["VertexID$45", Automatic, Center]}, {
          DynamicLocation["VertexID$29", Automatic, Center], 
          DynamicLocation["VertexID$35", Automatic, Center]}, {
          DynamicLocation["VertexID$29", Automatic, Center], 
          DynamicLocation["VertexID$39", Automatic, Center]}, {
          DynamicLocation["VertexID$29", Automatic, Center], 
          DynamicLocation["VertexID$44", Automatic, Center]}, {
          DynamicLocation["VertexID$29", Automatic, Center], 
          DynamicLocation["VertexID$46", Automatic, Center]}, {
          DynamicLocation["VertexID$30", Automatic, Center], 
          DynamicLocation["VertexID$36", Automatic, Center]}, {
          DynamicLocation["VertexID$30", Automatic, Center], 
          DynamicLocation["VertexID$40", Automatic, Center]}, {
          DynamicLocation["VertexID$30", Automatic, Center], 
          DynamicLocation["VertexID$45", Automatic, Center]}, {
          DynamicLocation["VertexID$30", Automatic, Center], 
          DynamicLocation["VertexID$47", Automatic, Center]}, {
          DynamicLocation["VertexID$31", Automatic, Center], 
          DynamicLocation["VertexID$37", Automatic, Center]}, {
          DynamicLocation["VertexID$31", Automatic, Center], 
          DynamicLocation["VertexID$46", Automatic, Center]}, {
          DynamicLocation["VertexID$31", Automatic, Center], 
          DynamicLocation["VertexID$48", Automatic, Center]}, {
          DynamicLocation["VertexID$32", Automatic, Center], 
          DynamicLocation["VertexID$38", Automatic, Center]}, {
          DynamicLocation["VertexID$32", Automatic, Center], 
          DynamicLocation["VertexID$47", Automatic, Center]}, {
          DynamicLocation["VertexID$33", Automatic, Center], 
          DynamicLocation["VertexID$44", Automatic, Center]}, {
          DynamicLocation["VertexID$33", Automatic, Center], 
          DynamicLocation["VertexID$50", Automatic, Center]}, {
          DynamicLocation["VertexID$33", Automatic, Center], 
          DynamicLocation["VertexID$51", Automatic, Center]}, {
          DynamicLocation["VertexID$34", Automatic, Center], 
          DynamicLocation["VertexID$43", Automatic, Center]}, {
          DynamicLocation["VertexID$34", Automatic, Center], 
          DynamicLocation["VertexID$49", Automatic, Center]}, {
          DynamicLocation["VertexID$35", Automatic, Center], 
          DynamicLocation["VertexID$42", Automatic, Center]}, {
          DynamicLocation["VertexID$35", Automatic, Center], 
          DynamicLocation["VertexID$45", Automatic, Center]}, {
          DynamicLocation["VertexID$35", Automatic, Center], 
          DynamicLocation["VertexID$49", Automatic, Center]}, {
          DynamicLocation["VertexID$35", Automatic, Center], 
          DynamicLocation["VertexID$52", Automatic, Center]}, {
          DynamicLocation["VertexID$36", Automatic, Center], 
          DynamicLocation["VertexID$41", Automatic, Center]}, {
          DynamicLocation["VertexID$36", Automatic, Center], 
          DynamicLocation["VertexID$46", Automatic, Center]}, {
          DynamicLocation["VertexID$36", Automatic, Center], 
          DynamicLocation["VertexID$51", Automatic, Center]}, {
          DynamicLocation["VertexID$36", Automatic, Center], 
          DynamicLocation["VertexID$53", Automatic, Center]}, {
          DynamicLocation["VertexID$37", Automatic, Center], 
          DynamicLocation["VertexID$43", Automatic, Center]}, {
          DynamicLocation["VertexID$37", Automatic, Center], 
          DynamicLocation["VertexID$47", Automatic, Center]}, {
          DynamicLocation["VertexID$37", Automatic, Center], 
          DynamicLocation["VertexID$52", Automatic, Center]}, {
          DynamicLocation["VertexID$37", Automatic, Center], 
          DynamicLocation["VertexID$54", Automatic, Center]}, {
          DynamicLocation["VertexID$38", Automatic, Center], 
          DynamicLocation["VertexID$44", Automatic, Center]}, {
          DynamicLocation["VertexID$38", Automatic, Center], 
          DynamicLocation["VertexID$48", Automatic, Center]}, {
          DynamicLocation["VertexID$38", Automatic, Center], 
          DynamicLocation["VertexID$53", Automatic, Center]}, {
          DynamicLocation["VertexID$38", Automatic, Center], 
          DynamicLocation["VertexID$55", Automatic, Center]}, {
          DynamicLocation["VertexID$39", Automatic, Center], 
          DynamicLocation["VertexID$45", Automatic, Center]}, {
          DynamicLocation["VertexID$39", Automatic, Center], 
          DynamicLocation["VertexID$54", Automatic, Center]}, {
          DynamicLocation["VertexID$39", Automatic, Center], 
          DynamicLocation["VertexID$56", Automatic, Center]}, {
          DynamicLocation["VertexID$40", Automatic, Center], 
          DynamicLocation["VertexID$46", Automatic, Center]}, {
          DynamicLocation["VertexID$40", Automatic, Center], 
          DynamicLocation["VertexID$55", Automatic, Center]}, {
          DynamicLocation["VertexID$41", Automatic, Center], 
          DynamicLocation["VertexID$52", Automatic, Center]}, {
          DynamicLocation["VertexID$41", Automatic, Center], 
          DynamicLocation["VertexID$58", Automatic, Center]}, {
          DynamicLocation["VertexID$41", Automatic, Center], 
          DynamicLocation["VertexID$59", Automatic, Center]}, {
          DynamicLocation["VertexID$42", Automatic, Center], 
          DynamicLocation["VertexID$51", Automatic, Center]}, {
          DynamicLocation["VertexID$42", Automatic, Center], 
          DynamicLocation["VertexID$57", Automatic, Center]}, {
          DynamicLocation["VertexID$43", Automatic, Center], 
          DynamicLocation["VertexID$50", Automatic, Center]}, {
          DynamicLocation["VertexID$43", Automatic, Center], 
          DynamicLocation["VertexID$53", Automatic, Center]}, {
          DynamicLocation["VertexID$43", Automatic, Center], 
          DynamicLocation["VertexID$57", Automatic, Center]}, {
          DynamicLocation["VertexID$43", Automatic, Center], 
          DynamicLocation["VertexID$60", Automatic, Center]}, {
          DynamicLocation["VertexID$44", Automatic, Center], 
          DynamicLocation["VertexID$49", Automatic, Center]}, {
          DynamicLocation["VertexID$44", Automatic, Center], 
          DynamicLocation["VertexID$54", Automatic, Center]}, {
          DynamicLocation["VertexID$44", Automatic, Center], 
          DynamicLocation["VertexID$59", Automatic, Center]}, {
          DynamicLocation["VertexID$44", Automatic, Center], 
          DynamicLocation["VertexID$61", Automatic, Center]}, {
          DynamicLocation["VertexID$45", Automatic, Center], 
          DynamicLocation["VertexID$51", Automatic, Center]}, {
          DynamicLocation["VertexID$45", Automatic, Center], 
          DynamicLocation["VertexID$55", Automatic, Center]}, {
          DynamicLocation["VertexID$45", Automatic, Center], 
          DynamicLocation["VertexID$60", Automatic, Center]}, {
          DynamicLocation["VertexID$45", Automatic, Center], 
          DynamicLocation["VertexID$62", Automatic, Center]}, {
          DynamicLocation["VertexID$46", Automatic, Center], 
          DynamicLocation["VertexID$52", Automatic, Center]}, {
          DynamicLocation["VertexID$46", Automatic, Center], 
          DynamicLocation["VertexID$56", Automatic, Center]}, {
          DynamicLocation["VertexID$46", Automatic, Center], 
          DynamicLocation["VertexID$61", Automatic, Center]}, {
          DynamicLocation["VertexID$46", Automatic, Center], 
          DynamicLocation["VertexID$63", Automatic, Center]}, {
          DynamicLocation["VertexID$47", Automatic, Center], 
          DynamicLocation["VertexID$53", Automatic, Center]}, {
          DynamicLocation["VertexID$47", Automatic, Center], 
          DynamicLocation["VertexID$62", Automatic, Center]}, {
          DynamicLocation["VertexID$47", Automatic, Center], 
          DynamicLocation["VertexID$64", Automatic, Center]}, {
          DynamicLocation["VertexID$48", Automatic, Center], 
          DynamicLocation["VertexID$54", Automatic, Center]}, {
          DynamicLocation["VertexID$48", Automatic, Center], 
          DynamicLocation["VertexID$63", Automatic, Center]}, {
          DynamicLocation["VertexID$49", Automatic, Center], 
          DynamicLocation["VertexID$60", Automatic, Center]}, {
          DynamicLocation["VertexID$50", Automatic, Center], 
          DynamicLocation["VertexID$59", Automatic, Center]}, {
          DynamicLocation["VertexID$51", Automatic, Center], 
          DynamicLocation["VertexID$58", Automatic, Center]}, {
          DynamicLocation["VertexID$51", Automatic, Center], 
          DynamicLocation["VertexID$61", Automatic, Center]}, {
          DynamicLocation["VertexID$52", Automatic, Center], 
          DynamicLocation["VertexID$57", Automatic, Center]}, {
          DynamicLocation["VertexID$52", Automatic, Center], 
          DynamicLocation["VertexID$62", Automatic, Center]}, {
          DynamicLocation["VertexID$53", Automatic, Center], 
          DynamicLocation["VertexID$59", Automatic, Center]}, {
          DynamicLocation["VertexID$53", Automatic, Center], 
          DynamicLocation["VertexID$63", Automatic, Center]}, {
          DynamicLocation["VertexID$54", Automatic, Center], 
          DynamicLocation["VertexID$60", Automatic, Center]}, {
          DynamicLocation["VertexID$54", Automatic, Center], 
          DynamicLocation["VertexID$64", Automatic, Center]}, {
          DynamicLocation["VertexID$55", Automatic, Center], 
          DynamicLocation["VertexID$61", Automatic, Center]}, {
          DynamicLocation["VertexID$56", Automatic, Center], 
          DynamicLocation["VertexID$62", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[
        DiskBox[{0., 0.08553515388695532}, 0.03365513721870758], 
        "DynamicName", BoxID -> "VertexID$1"], 
       TagBox[
        DiskBox[{0.972927037527402, 0.6096461471964894}, 0.03365513721870758],
         "DynamicName", BoxID -> "VertexID$2"], 
       TagBox[
        DiskBox[{0.599578321090541, 0.9800672488664548}, 0.03365513721870758],
         "DynamicName", BoxID -> "VertexID$3"], 
       TagBox[
        DiskBox[{0.508336548268876, 0.19998939380286007`}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$4"], 
       TagBox[
        DiskBox[{1.48970069260852, 0.6313712748675975}, 0.03365513721870758], 
        "DynamicName", BoxID -> "VertexID$5"], 
       TagBox[
        DiskBox[{0.20885313796064375`, 0.9924046689570326}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$6"], 
       TagBox[
        DiskBox[{1.0143759752433585`, 1.0095709591045363`}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$7"], 
       TagBox[
        DiskBox[{0.9610106886703718, 0.2135313478356955}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$8"], 
       TagBox[
        DiskBox[{0.1731384465010779, 0.5430408201629617}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$9"], 
       TagBox[
        DiskBox[{1.9887355909203623`, 0.623707262045512}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$10"], 
       TagBox[
        DiskBox[{1.5336810387443374`, 1.0184241131589276`}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$11"], 
       TagBox[
        DiskBox[{1.517988561144122, 0.2391241026451345}, 0.03365513721870758],
         "DynamicName", BoxID -> "VertexID$12"], 
       TagBox[
        DiskBox[{0.7134755662206245, 0.7004246978848463}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$13"], 
       TagBox[
        DiskBox[{2.513769926432562, 0.5814151287347853}, 0.03365513721870758],
         "DynamicName", BoxID -> "VertexID$14"], 
       TagBox[
        DiskBox[{1.965881278334022, 1.0154809392086974`}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$15"], 
       TagBox[
        DiskBox[{1.970434349511057, 0.2337325757181039}, 0.03365513721870758],
         "DynamicName", BoxID -> "VertexID$16"], 
       TagBox[
        DiskBox[{2.7896215867638716`, 0.690932715163683}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$17"], 
       TagBox[
        DiskBox[{2.478937108886183, 0.9920052005533105}, 0.03365513721870758],
         "DynamicName", BoxID -> "VertexID$18"], 
       TagBox[
        DiskBox[{2.501784049854333, 0.1900659560670317}, 0.03365513721870758],
         "DynamicName", BoxID -> "VertexID$19"], 
       TagBox[
        DiskBox[{3.289360254366241, 0.4876089268993553}, 0.03365513721870758],
         "DynamicName", BoxID -> "VertexID$20"], 
       TagBox[
        DiskBox[{2.8833060502468464`, 0.9564199196543814}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$21"], 
       TagBox[
        DiskBox[{2.944617564999361, 0.14367546544877996`}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$22"], 
       TagBox[
        DiskBox[{3.27649463477682, 0.9363575108531549}, 0.03365513721870758], 
        "DynamicName", BoxID -> "VertexID$23"], 
       TagBox[
        DiskBox[{3.4275120439185667`, 0.}, 0.03365513721870758], 
        "DynamicName", BoxID -> "VertexID$24"], 
       TagBox[
        DiskBox[{0.6463092422047372, 1.5018489129737174`}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$25"], 
       TagBox[
        DiskBox[{0.2555920089663235, 1.5175320460374333`}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$26"], 
       TagBox[
        DiskBox[{1.0364311581314607`, 1.5236541101484593`}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$27"], 
       TagBox[
        DiskBox[{1.501623467196144, 1.487585689983258}, 0.03365513721870758], 
        "DynamicName", BoxID -> "VertexID$28"], 
       TagBox[
        DiskBox[{2.002901958149974, 1.4810846646766722`}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$29"], 
       TagBox[
        DiskBox[{2.471776219812422, 1.5108557191728953`}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$30"], 
       TagBox[
        DiskBox[{2.8585110424512656`, 1.471126224572271}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$31"], 
       TagBox[
        DiskBox[{3.249804106784594, 1.4966341288835816`}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$32"], 
       TagBox[
        DiskBox[{0.6515623032634943, 1.9982440163221018`}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$33"], 
       TagBox[
        DiskBox[{0.259509505544548, 1.9721819583110953`}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$34"], 
       TagBox[
        DiskBox[{1.0398518073508116`, 1.9566697766410566`}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$35"], 
       TagBox[
        DiskBox[{1.5087236956614214`, 1.986448299684342}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$36"], 
       TagBox[
        DiskBox[{2.0081253981881, 1.9811353495316673`}, 0.03365513721870758], 
        "DynamicName", BoxID -> "VertexID$37"], 
       TagBox[
        DiskBox[{2.4734322794810337`, 1.9458803553123791`}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$38"], 
       TagBox[
        DiskBox[{2.865310111579329, 1.9666730525299654`}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$39"], 
       TagBox[
        DiskBox[{3.257029587503359, 1.9506249768801047`}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$40"], 
       TagBox[
        DiskBox[{0.6273027476995665, 2.511307396361418}, 0.03365513721870758],
         "DynamicName", BoxID -> "VertexID$41"], 
       TagBox[
        DiskBox[{0.23433918476859028`, 2.5277299619445177`}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$42"], 
       TagBox[
        DiskBox[{1.0297069504094643`, 2.4749573144358195`}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$43"], 
       TagBox[
        DiskBox[{1.5434870950158417`, 2.4524960663432407`}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$44"], 
       TagBox[
        DiskBox[{1.9777978054836993`, 2.4489302194153457`}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$45"], 
       TagBox[
        DiskBox[{2.4959208006957105`, 2.459360804308875}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$46"], 
       TagBox[
        DiskBox[{2.9063024163056017`, 2.491751844704886}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$47"], 
       TagBox[
        DiskBox[{3.297642750477827, 2.484258734923639}, 0.03365513721870758], 
        "DynamicName", BoxID -> "VertexID$48"], 
       TagBox[
        DiskBox[{0.7221640934647022, 2.7767824946871325`}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$49"], 
       TagBox[
        DiskBox[{0.21264584023537747`, 2.9718384334523904`}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$50"], 
       TagBox[
        DiskBox[{0.998011666782957, 2.88639509010613}, 0.03365513721870758], 
        "DynamicName", BoxID -> "VertexID$51"], 
       TagBox[
        DiskBox[{1.5204203929281064`, 2.843831470493417}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$52"], 
       TagBox[
        DiskBox[{2.0159688467914343`, 2.8380014142955416`}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$53"], 
       TagBox[
        DiskBox[{2.5329867280211706`, 2.861517478827138}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$54"], 
       TagBox[
        DiskBox[{2.7997926887058213`, 2.767357770146019}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$55"], 
       TagBox[
        DiskBox[{3.3392561528529567`, 2.927882066243744}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$56"], 
       TagBox[
        DiskBox[{0.5607996801334136, 3.3175751148589114`}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$57"], 
       TagBox[
        DiskBox[{0.08818403201923153, 3.4702158813763706`}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$58"], 
       TagBox[
        DiskBox[{1.001783729203451, 3.2747339033143112`}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$59"], 
       TagBox[
        DiskBox[{1.5383131019865444`, 3.2348598738537704`}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$60"], 
       TagBox[
        DiskBox[{1.9923518459363077`, 3.228552442370707}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$61"], 
       TagBox[
        DiskBox[{2.5457641346465794`, 3.257039005122765}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$62"], 
       TagBox[
        DiskBox[{2.9909473754300313`, 3.276724939023854}, 
         0.03365513721870758], "DynamicName", BoxID -> "VertexID$63"], 
       TagBox[
        DiskBox[{3.490273400894745, 3.4031436538324797`}, 
         0.03365513721870758], "DynamicName", BoxID -> 
        "VertexID$64"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{7.900000000000002, 437.1}, {-216.45599999999993`, 
       210.33546288036374`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output",
 CellLabel->"Out[2]="]
}, Open  ]],

Cell["Now that we have the graph, we can find a tour.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"soln", "=", 
  RowBox[{"FindHamiltonianCycle", "[", "standardBoard", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"2", ",", "8"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "8"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"4", ",", "7"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "7"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"6", ",", "8"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", "8"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"8", ",", "7"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"8", ",", "7"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"6", ",", "6"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", "6"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"8", ",", "5"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"8", ",", "5"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"6", ",", "4"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", "4"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"8", ",", "3"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"8", ",", "3"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"7", ",", "1"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"7", ",", "1"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"5", ",", "2"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "2"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"4", ",", "4"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "4"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"3", ",", "6"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "6"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"4", ",", "8"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "8"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"2", ",", "7"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "7"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"4", ",", "2"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "2"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"6", ",", "1"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", "1"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"8", ",", "2"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"8", ",", "2"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"6", ",", "3"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", "3"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"8", ",", "4"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"8", ",", "4"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"6", ",", "5"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", "5"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"8", ",", "6"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"8", ",", "6"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"7", ",", "8"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"7", ",", "8"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"5", ",", "7"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "7"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"4", ",", "5"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "5"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"3", ",", "7"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "7"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"1", ",", "8"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "8"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "6"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"3", ",", "8"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "8"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"1", ",", "7"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "7"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"4", ",", "1"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "1"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"4", ",", "3"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "3"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"6", ",", "2"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", "2"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"8", ",", "1"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"8", ",", "1"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"7", ",", "3"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"7", ",", "3"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"5", ",", "4"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "4"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"7", ",", "5"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"7", ",", "5"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"5", ",", "6"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "6"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"7", ",", "7"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"7", ",", "7"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"5", ",", "8"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "8"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"4", ",", "6"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "6"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"6", ",", "7"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", "7"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"8", ",", "8"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"8", ",", "8"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"7", ",", "6"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"7", ",", "6"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"5", ",", "5"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "5"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"7", ",", "4"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"7", ",", "4"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"5", ",", "3"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "3"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"7", ",", "2"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"7", ",", "2"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"5", ",", "1"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "1"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}]}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}], "\[UndirectedEdge]", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}]}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell["Which looks very nice visualized on a chess board...", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Graphics", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"EdgeForm", "[", "Black", "]"}], ",", 
        RowBox[{"GrayLevel", "[", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{
            RowBox[{"x", "+", "y"}], ",", "2"}], "]"}], "+", "0.6"}], "]"}], 
        ",", 
        RowBox[{"Rectangle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"x", ",", "y"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"x", "+", "1"}], ",", 
            RowBox[{"y", "+", "1"}]}], "}"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0.5", ",", "7.5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", "0.5", ",", "7.5"}], "}"}]}], "]"}], "]"}], ",", 
   RowBox[{"ListLinePlot", "[", 
    RowBox[{
     RowBox[{"First", "/@", 
      RowBox[{"First", "@", "soln"}]}], ",", 
     RowBox[{"Mesh", "\[Rule]", "All"}]}], "]"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{{
     {GrayLevel[1.6], EdgeForm[GrayLevel[0]], RectangleBox[{0.5, 0.5}]}, 
     {GrayLevel[0.6], EdgeForm[GrayLevel[0]], RectangleBox[{0.5, 1.5}]}, 
     {GrayLevel[1.6], EdgeForm[GrayLevel[0]], RectangleBox[{0.5, 2.5}]}, 
     {GrayLevel[0.6], EdgeForm[GrayLevel[0]], RectangleBox[{0.5, 3.5}]}, 
     {GrayLevel[1.6], EdgeForm[GrayLevel[0]], RectangleBox[{0.5, 4.5}]}, 
     {GrayLevel[0.6], EdgeForm[GrayLevel[0]], RectangleBox[{0.5, 5.5}]}, 
     {GrayLevel[1.6], EdgeForm[GrayLevel[0]], RectangleBox[{0.5, 6.5}]}, 
     {GrayLevel[0.6], EdgeForm[GrayLevel[0]], RectangleBox[{0.5, 7.5}]}}, {
     {GrayLevel[0.6], EdgeForm[GrayLevel[0]], RectangleBox[{1.5, 0.5}]}, 
     {GrayLevel[1.6], EdgeForm[GrayLevel[0]], RectangleBox[{1.5, 1.5}]}, 
     {GrayLevel[0.6], EdgeForm[GrayLevel[0]], RectangleBox[{1.5, 2.5}]}, 
     {GrayLevel[1.6], EdgeForm[GrayLevel[0]], RectangleBox[{1.5, 3.5}]}, 
     {GrayLevel[0.6], EdgeForm[GrayLevel[0]], RectangleBox[{1.5, 4.5}]}, 
     {GrayLevel[1.6], EdgeForm[GrayLevel[0]], RectangleBox[{1.5, 5.5}]}, 
     {GrayLevel[0.6], EdgeForm[GrayLevel[0]], RectangleBox[{1.5, 6.5}]}, 
     {GrayLevel[1.6], EdgeForm[GrayLevel[0]], RectangleBox[{1.5, 7.5}]}}, {
     {GrayLevel[1.6], EdgeForm[GrayLevel[0]], RectangleBox[{2.5, 0.5}]}, 
     {GrayLevel[0.6], EdgeForm[GrayLevel[0]], RectangleBox[{2.5, 1.5}]}, 
     {GrayLevel[1.6], EdgeForm[GrayLevel[0]], RectangleBox[{2.5, 2.5}]}, 
     {GrayLevel[0.6], EdgeForm[GrayLevel[0]], RectangleBox[{2.5, 3.5}]}, 
     {GrayLevel[1.6], EdgeForm[GrayLevel[0]], RectangleBox[{2.5, 4.5}]}, 
     {GrayLevel[0.6], EdgeForm[GrayLevel[0]], RectangleBox[{2.5, 5.5}]}, 
     {GrayLevel[1.6], EdgeForm[GrayLevel[0]], RectangleBox[{2.5, 6.5}]}, 
     {GrayLevel[0.6], EdgeForm[GrayLevel[0]], RectangleBox[{2.5, 7.5}]}}, {
     {GrayLevel[0.6], EdgeForm[GrayLevel[0]], RectangleBox[{3.5, 0.5}]}, 
     {GrayLevel[1.6], EdgeForm[GrayLevel[0]], RectangleBox[{3.5, 1.5}]}, 
     {GrayLevel[0.6], EdgeForm[GrayLevel[0]], RectangleBox[{3.5, 2.5}]}, 
     {GrayLevel[1.6], EdgeForm[GrayLevel[0]], RectangleBox[{3.5, 3.5}]}, 
     {GrayLevel[0.6], EdgeForm[GrayLevel[0]], RectangleBox[{3.5, 4.5}]}, 
     {GrayLevel[1.6], EdgeForm[GrayLevel[0]], RectangleBox[{3.5, 5.5}]}, 
     {GrayLevel[0.6], EdgeForm[GrayLevel[0]], RectangleBox[{3.5, 6.5}]}, 
     {GrayLevel[1.6], EdgeForm[GrayLevel[0]], RectangleBox[{3.5, 7.5}]}}, {
     {GrayLevel[1.6], EdgeForm[GrayLevel[0]], RectangleBox[{4.5, 0.5}]}, 
     {GrayLevel[0.6], EdgeForm[GrayLevel[0]], RectangleBox[{4.5, 1.5}]}, 
     {GrayLevel[1.6], EdgeForm[GrayLevel[0]], RectangleBox[{4.5, 2.5}]}, 
     {GrayLevel[0.6], EdgeForm[GrayLevel[0]], RectangleBox[{4.5, 3.5}]}, 
     {GrayLevel[1.6], EdgeForm[GrayLevel[0]], RectangleBox[{4.5, 4.5}]}, 
     {GrayLevel[0.6], EdgeForm[GrayLevel[0]], RectangleBox[{4.5, 5.5}]}, 
     {GrayLevel[1.6], EdgeForm[GrayLevel[0]], RectangleBox[{4.5, 6.5}]}, 
     {GrayLevel[0.6], EdgeForm[GrayLevel[0]], RectangleBox[{4.5, 7.5}]}}, {
     {GrayLevel[0.6], EdgeForm[GrayLevel[0]], RectangleBox[{5.5, 0.5}]}, 
     {GrayLevel[1.6], EdgeForm[GrayLevel[0]], RectangleBox[{5.5, 1.5}]}, 
     {GrayLevel[0.6], EdgeForm[GrayLevel[0]], RectangleBox[{5.5, 2.5}]}, 
     {GrayLevel[1.6], EdgeForm[GrayLevel[0]], RectangleBox[{5.5, 3.5}]}, 
     {GrayLevel[0.6], EdgeForm[GrayLevel[0]], RectangleBox[{5.5, 4.5}]}, 
     {GrayLevel[1.6], EdgeForm[GrayLevel[0]], RectangleBox[{5.5, 5.5}]}, 
     {GrayLevel[0.6], EdgeForm[GrayLevel[0]], RectangleBox[{5.5, 6.5}]}, 
     {GrayLevel[1.6], EdgeForm[GrayLevel[0]], RectangleBox[{5.5, 7.5}]}}, {
     {GrayLevel[1.6], EdgeForm[GrayLevel[0]], RectangleBox[{6.5, 0.5}]}, 
     {GrayLevel[0.6], EdgeForm[GrayLevel[0]], RectangleBox[{6.5, 1.5}]}, 
     {GrayLevel[1.6], EdgeForm[GrayLevel[0]], RectangleBox[{6.5, 2.5}]}, 
     {GrayLevel[0.6], EdgeForm[GrayLevel[0]], RectangleBox[{6.5, 3.5}]}, 
     {GrayLevel[1.6], EdgeForm[GrayLevel[0]], RectangleBox[{6.5, 4.5}]}, 
     {GrayLevel[0.6], EdgeForm[GrayLevel[0]], RectangleBox[{6.5, 5.5}]}, 
     {GrayLevel[1.6], EdgeForm[GrayLevel[0]], RectangleBox[{6.5, 6.5}]}, 
     {GrayLevel[0.6], EdgeForm[GrayLevel[0]], RectangleBox[{6.5, 7.5}]}}, {
     {GrayLevel[0.6], EdgeForm[GrayLevel[0]], RectangleBox[{7.5, 0.5}]}, 
     {GrayLevel[1.6], EdgeForm[GrayLevel[0]], RectangleBox[{7.5, 1.5}]}, 
     {GrayLevel[0.6], EdgeForm[GrayLevel[0]], RectangleBox[{7.5, 2.5}]}, 
     {GrayLevel[1.6], EdgeForm[GrayLevel[0]], RectangleBox[{7.5, 3.5}]}, 
     {GrayLevel[0.6], EdgeForm[GrayLevel[0]], RectangleBox[{7.5, 4.5}]}, 
     {GrayLevel[1.6], EdgeForm[GrayLevel[0]], RectangleBox[{7.5, 5.5}]}, 
     {GrayLevel[0.6], EdgeForm[GrayLevel[0]], RectangleBox[{7.5, 6.5}]}, 
     {GrayLevel[1.6], EdgeForm[GrayLevel[0]], 
      RectangleBox[{7.5, 7.5}]}}}, {{}, GraphicsComplexBox[CompressedData["
1:eJyNkjEKwzAQBEUqlypUpLjCeUn8hjwhkDpfzxPi2EzhgSUWiIPdvdWhvdvz
/XhdWmvLen91P5/7sW70eibVpKN26a7iZ+lqOepmVfPWDeFdPHPjw1z0eW4q
fcmXvuRLv33pw5c++8Lj43+DH+LBS/gQ3oWnfzo7F/qSfoifxBv3v6U9A3de
vJdy9B567uRTwr13FXQpt5RT2nu/ezbH/zl8ATFWON4=
     "], {{{}, {}, 
       {RGBColor[0.24720000000000014`, 0.24, 0.6], 
        LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
         18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
         35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
         52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64}]}}, {
       {RGBColor[0.24720000000000014`, 0.24, 0.6], 
        PointBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
         18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
         35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
         52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 
         64}]}, {}, {}}}], {}}}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "I understand that this problem is often used as an exercise in computer \
science courses, and you can find some iterative solutions and specific \
solutions at ",
 ButtonBox["demonstrations.wolfram.com",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/search.html?query=knights%20tour"],
     None},
  ButtonNote->
   "http://demonstrations.wolfram.com/search.html?query=knights%20tour"],
 ".  But at four lines, this graph theory solution, isn\[CloseCurlyQuote]t \
too much of a challenge. Indeed, it seemed a little unsatisfying to stop \
here. \n\nGiving FindHamiltonianCycle a second argument finds more than one \
tour. But scrolling through a notebook of the first 1000 didn\
\[CloseCurlyQuote]t reveal anything interesting. And the properties of \
different sized chess boards have been well studied. So I decided to  extend \
the idea in a slightly more whimsical way.\n\nOddly all the definitions of \
knights tour that I found on the web assume a recangular space. Indeed ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " contains a built-in function ",
 ButtonBox["KnightTourGraph",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/mathematica/ref/KnightTourGraph.html"], 
    None},
  ButtonNote->
   "http://reference.wolfram.com/mathematica/ref/KnightTourGraph.html"],
 " which does roughly the same as my knightGraph function but assumes a \
rectangular grid. But if I bring in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s image processing, it is easy to generate the knight \
tour graph over points in non-rectangular shapes. \n\nFirst I ",
 ButtonBox["Binarize",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/mathematica/ref/Binarize.html"], None},
  ButtonNote->"http://reference.wolfram.com/mathematica/ref/Binarize.html"],
 " the pixels of some source image (there is no \[OpenCurlyDoubleQuote]gray\
\[CloseCurlyDoubleQuote] when it comes to whether the knight is allowed to \
visit), then select out the coordinates of the black pixels, and finally \
there is a change of coordinate space between my plotting function and image \
pixels."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"imageBlackPoints", "[", "img_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Position", "[", 
     RowBox[{
      RowBox[{"ImageData", "[", 
       RowBox[{"Binarize", "[", 
        RowBox[{"Rasterize", "[", "img", "]"}], "]"}], "]"}], ",", "0"}], 
     "]"}], "/.", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"row_Integer", ",", "col_Integer"}], "}"}], "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"col", ",", 
       RowBox[{"-", "row"}]}], "}"}]}]}]}], ";"}]], "Input",
 CellLabel->"In[21]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"imageToKnightGraph", "[", "img_", "]"}], ":=", 
  RowBox[{"knightGraph", "[", 
   RowBox[{"imageBlackPoints", "[", "img", "]"}], "]"}]}]], "Input",
 CellLabel->"In[22]:="],

Cell["\<\
Now I just solve and plot that graph as before, but this time visualize with \
the black pixels, instead of a chess-board grid.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"showImageTour", "[", "img_", "]"}], ":=", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"Graphics", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"GrayLevel", "[", "0.7", "]"}], ",", 
       RowBox[{"EdgeForm", "[", "Black", "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Rectangle", "[", 
          RowBox[{
           RowBox[{"#", "-", 
            RowBox[{"1", "/", "2"}]}], ",", 
           RowBox[{"#", "+", 
            RowBox[{"1", "/", "2"}]}]}], "]"}], "&"}], "/@", 
        RowBox[{"imageBlackPoints", "[", "img", "]"}]}]}], "}"}], "]"}], ",", 
    
    RowBox[{"ListLinePlot", "[", 
     RowBox[{
      RowBox[{"First", "/@", 
       RowBox[{"First", "@", "\[IndentingNewLine]", 
        RowBox[{"FindHamiltonianCycle", "[", 
         RowBox[{"imageToKnightGraph", "[", "img", "]"}], "]"}]}]}], ",", 
      RowBox[{"Mesh", "\[Rule]", "All"}]}], "]"}]}], "]"}]}]], "Input",
 CellLabel->"In[23]:="],

Cell[TextData[{
 "It turns out that most irregular shapes do not have a closed knights tour \
but messing around with the image size can find exceptions. So a bit of \
search code is needed. This one takes a single character and rasterizes it at \
different font sizes and returns the size for which a tour exists. The ",
 ButtonBox["Monitor",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/mathematica/ref/Monitor.html"], None},
  ButtonNote->"http://reference.wolfram.com/mathematica/ref/Monitor.html"],
 " part lets you watch the progress; tour finding scales poorly and can get \
very slow if you let the font sizes grow too big..."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"imageKnightTourQ", "[", "img_", "]"}], ":=", 
  RowBox[{"HamiltonianGraphQ", "[", 
   RowBox[{"imageToKnightGraph", "[", "img", "]"}], "]"}]}]], "Input",
 CellLabel->"In[24]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"characterSizeFinder", "[", 
    RowBox[{"char_", ",", "max_"}], "]"}], ":=", 
   RowBox[{"Monitor", "[", 
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"Range", "[", 
        RowBox[{"8", ",", "max"}], "]"}], ",", 
       RowBox[{
        RowBox[{"imageKnightTourQ", "[", 
         RowBox[{"Style", "[", 
          RowBox[{"char", ",", 
           RowBox[{"current", "=", "#"}]}], "]"}], "]"}], "&"}]}], "]"}], ",",
      "current"}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[27]:="],

Cell["Lets start by searching simple filled circles", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"characterSizeFinder", "[", 
  RowBox[{"\"\<\[FilledCircle]\>\"", ",", "50"}], "]"}]], "Input",
 CellLabel->"In[28]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "8", ",", "10", ",", "13", ",", "15", ",", "17", ",", "39", ",", "43"}], 
  "}"}]], "Output",
 CellLabel->"Out[28]="]
}, Open  ]],

Cell["\<\
So out of the 42 sizes tested, only these five have solutions. The smaller, \
more crowded font sizes produce more irregular tour paths...\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"showImageTour", "[", 
  RowBox[{"Style", "[", 
   RowBox[{"\"\<\[FilledCircle]\>\"", ",", "15"}], "]"}], "]"}]], "Input",
 CellLabel->"In[29]:="],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0.7], EdgeForm[GrayLevel[0]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-9, 2]}, {2.5, -4.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-9, 2]}, {3.5, -4.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-9, 2]}, {4.5, -4.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-9, 2]}, {5.5, -4.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-9, 2]}, {6.5, -4.5}]], 
    RectangleBox[NCache[{Rational[3, 2], Rational[-11, 2]}, {1.5, -5.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-11, 2]}, {2.5, -5.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-11, 2]}, {3.5, -5.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-11, 2]}, {4.5, -5.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-11, 2]}, {5.5, -5.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-11, 2]}, {6.5, -5.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-11, 2]}, {7.5, -5.5}]], 
    RectangleBox[NCache[{Rational[1, 2], Rational[-13, 2]}, {0.5, -6.5}]], 
    RectangleBox[NCache[{Rational[3, 2], Rational[-13, 2]}, {1.5, -6.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-13, 2]}, {2.5, -6.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-13, 2]}, {3.5, -6.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-13, 2]}, {4.5, -6.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-13, 2]}, {5.5, -6.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-13, 2]}, {6.5, -6.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-13, 2]}, {7.5, -6.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-13, 2]}, {8.5, -6.5}]], 
    RectangleBox[NCache[{Rational[1, 2], Rational[-15, 2]}, {0.5, -7.5}]], 
    RectangleBox[NCache[{Rational[3, 2], Rational[-15, 2]}, {1.5, -7.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-15, 2]}, {2.5, -7.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-15, 2]}, {3.5, -7.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-15, 2]}, {4.5, -7.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-15, 2]}, {5.5, -7.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-15, 2]}, {6.5, -7.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-15, 2]}, {7.5, -7.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-15, 2]}, {8.5, -7.5}]], 
    RectangleBox[NCache[{Rational[1, 2], Rational[-17, 2]}, {0.5, -8.5}]], 
    RectangleBox[NCache[{Rational[3, 2], Rational[-17, 2]}, {1.5, -8.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-17, 2]}, {2.5, -8.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-17, 2]}, {3.5, -8.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-17, 2]}, {4.5, -8.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-17, 2]}, {5.5, -8.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-17, 2]}, {6.5, -8.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-17, 2]}, {7.5, -8.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-17, 2]}, {8.5, -8.5}]], 
    RectangleBox[NCache[{Rational[1, 2], Rational[-19, 2]}, {0.5, -9.5}]], 
    RectangleBox[NCache[{Rational[3, 2], Rational[-19, 2]}, {1.5, -9.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-19, 2]}, {2.5, -9.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-19, 2]}, {3.5, -9.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-19, 2]}, {4.5, -9.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-19, 2]}, {5.5, -9.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-19, 2]}, {6.5, -9.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-19, 2]}, {7.5, -9.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-19, 2]}, {8.5, -9.5}]], 
    RectangleBox[NCache[{Rational[3, 2], Rational[-21, 2]}, {1.5, -10.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-21, 2]}, {2.5, -10.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-21, 2]}, {3.5, -10.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-21, 2]}, {4.5, -10.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-21, 2]}, {5.5, -10.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-21, 2]}, {6.5, -10.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-21, 2]}, {7.5, -10.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-23, 2]}, {2.5, -11.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-23, 2]}, {3.5, -11.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-23, 2]}, {4.5, -11.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-23, 2]}, {5.5, -11.5}]], 
    RectangleBox[
     NCache[{Rational[13, 2], Rational[-23, 2]}, {6.5, -11.5}]]}, {{}, 
    GraphicsComplexBox[CompressedData["
1:eJx1kzEKwzAMRUOnjB48ePDgmuBTFJoz9AiFzr1ijtQjtCV6Qx4kEIzyvr4U
Kbk+34/XZZqm2+/+n/v1ue9n3+LBuh814nk9cvRN+iXiFPGIuIjn9Zhf5Y9+
SN+lx6+f8CZexYv84dTPEacTfYp4PtHjx3zoh/nhN0tPPn7kW0/9LH0Vb8rn
/ap4E+/inrf3V8WLOP1lceq53yxexL2vJu7vYai+v1fymW8Rpz/2QX/s0/8L
fuRTj/wu/ZAensXRL9sXjjBMqg==
     "], {{{}, {}, 
       {RGBColor[0.24720000000000014`, 0.24, 0.6], 
        LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
         18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
         35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
         52, 53, 54, 55, 56, 57, 58, 59, 60}]}}, {
       {RGBColor[0.24720000000000014`, 0.24, 0.6], 
        PointBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
         18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
         35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
         52, 53, 54, 55, 56, 57, 58, 59, 60}]}, {}, {}}}], {}}}]], "Output",
 CellLabel->"Out[29]="]
}, Open  ]],

Cell["But larger image sizes make the shape more recognizable...", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"showImageTour", "[", 
  RowBox[{"Style", "[", 
   RowBox[{"\"\<\[FilledCircle]\>\"", ",", "43"}], "]"}], "]"}]], "Input",
 CellLabel->"In[30]:="],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0.7], EdgeForm[GrayLevel[0]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-19, 2]}, {8.5, -9.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-19, 2]}, {9.5, -9.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-19, 2]}, {10.5, -9.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-19, 2]}, {11.5, -9.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-19, 2]}, {12.5, -9.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-19, 2]}, {13.5, -9.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-19, 2]}, {14.5, -9.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-19, 2]}, {15.5, -9.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-19, 2]}, {16.5, -9.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-19, 2]}, {17.5, -9.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-21, 2]}, {6.5, -10.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-21, 2]}, {7.5, -10.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-21, 2]}, {8.5, -10.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-21, 2]}, {9.5, -10.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-21, 2]}, {10.5, -10.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-21, 2]}, {11.5, -10.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-21, 2]}, {12.5, -10.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-21, 2]}, {13.5, -10.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-21, 2]}, {14.5, -10.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-21, 2]}, {15.5, -10.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-21, 2]}, {16.5, -10.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-21, 2]}, {17.5, -10.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-21, 2]}, {18.5, -10.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-21, 2]}, {19.5, -10.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-23, 2]}, {5.5, -11.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-23, 2]}, {6.5, -11.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-23, 2]}, {7.5, -11.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-23, 2]}, {8.5, -11.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-23, 2]}, {9.5, -11.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-23, 2]}, {10.5, -11.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-23, 2]}, {11.5, -11.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-23, 2]}, {12.5, -11.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-23, 2]}, {13.5, -11.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-23, 2]}, {14.5, -11.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-23, 2]}, {15.5, -11.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-23, 2]}, {16.5, -11.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-23, 2]}, {17.5, -11.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-23, 2]}, {18.5, -11.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-23, 2]}, {19.5, -11.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-23, 2]}, {20.5, -11.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-25, 2]}, {4.5, -12.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-25, 2]}, {5.5, -12.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-25, 2]}, {6.5, -12.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-25, 2]}, {7.5, -12.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-25, 2]}, {8.5, -12.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-25, 2]}, {9.5, -12.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-25, 2]}, {10.5, -12.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-25, 2]}, {11.5, -12.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-25, 2]}, {12.5, -12.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-25, 2]}, {13.5, -12.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-25, 2]}, {14.5, -12.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-25, 2]}, {15.5, -12.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-25, 2]}, {16.5, -12.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-25, 2]}, {17.5, -12.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-25, 2]}, {18.5, -12.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-25, 2]}, {19.5, -12.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-25, 2]}, {20.5, -12.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-25, 2]}, {21.5, -12.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-27, 2]}, {3.5, -13.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-27, 2]}, {4.5, -13.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-27, 2]}, {5.5, -13.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-27, 2]}, {6.5, -13.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-27, 2]}, {7.5, -13.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-27, 2]}, {8.5, -13.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-27, 2]}, {9.5, -13.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-27, 2]}, {10.5, -13.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-27, 2]}, {11.5, -13.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-27, 2]}, {12.5, -13.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-27, 2]}, {13.5, -13.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-27, 2]}, {14.5, -13.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-27, 2]}, {15.5, -13.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-27, 2]}, {16.5, -13.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-27, 2]}, {17.5, -13.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-27, 2]}, {18.5, -13.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-27, 2]}, {19.5, -13.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-27, 2]}, {20.5, -13.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-27, 2]}, {21.5, -13.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-27, 2]}, {22.5, -13.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-29, 2]}, {2.5, -14.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-29, 2]}, {3.5, -14.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-29, 2]}, {4.5, -14.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-29, 2]}, {5.5, -14.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-29, 2]}, {6.5, -14.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-29, 2]}, {7.5, -14.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-29, 2]}, {8.5, -14.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-29, 2]}, {9.5, -14.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-29, 2]}, {10.5, -14.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-29, 2]}, {11.5, -14.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-29, 2]}, {12.5, -14.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-29, 2]}, {13.5, -14.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-29, 2]}, {14.5, -14.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-29, 2]}, {15.5, -14.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-29, 2]}, {16.5, -14.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-29, 2]}, {17.5, -14.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-29, 2]}, {18.5, -14.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-29, 2]}, {19.5, -14.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-29, 2]}, {20.5, -14.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-29, 2]}, {21.5, -14.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-29, 2]}, {22.5, -14.5}]], 
    RectangleBox[NCache[{Rational[47, 2], Rational[-29, 2]}, {23.5, -14.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-31, 2]}, {2.5, -15.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-31, 2]}, {3.5, -15.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-31, 2]}, {4.5, -15.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-31, 2]}, {5.5, -15.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-31, 2]}, {6.5, -15.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-31, 2]}, {7.5, -15.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-31, 2]}, {8.5, -15.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-31, 2]}, {9.5, -15.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-31, 2]}, {10.5, -15.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-31, 2]}, {11.5, -15.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-31, 2]}, {12.5, -15.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-31, 2]}, {13.5, -15.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-31, 2]}, {14.5, -15.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-31, 2]}, {15.5, -15.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-31, 2]}, {16.5, -15.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-31, 2]}, {17.5, -15.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-31, 2]}, {18.5, -15.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-31, 2]}, {19.5, -15.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-31, 2]}, {20.5, -15.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-31, 2]}, {21.5, -15.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-31, 2]}, {22.5, -15.5}]], 
    RectangleBox[NCache[{Rational[47, 2], Rational[-31, 2]}, {23.5, -15.5}]], 
    RectangleBox[NCache[{Rational[3, 2], Rational[-33, 2]}, {1.5, -16.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-33, 2]}, {2.5, -16.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-33, 2]}, {3.5, -16.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-33, 2]}, {4.5, -16.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-33, 2]}, {5.5, -16.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-33, 2]}, {6.5, -16.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-33, 2]}, {7.5, -16.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-33, 2]}, {8.5, -16.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-33, 2]}, {9.5, -16.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-33, 2]}, {10.5, -16.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-33, 2]}, {11.5, -16.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-33, 2]}, {12.5, -16.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-33, 2]}, {13.5, -16.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-33, 2]}, {14.5, -16.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-33, 2]}, {15.5, -16.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-33, 2]}, {16.5, -16.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-33, 2]}, {17.5, -16.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-33, 2]}, {18.5, -16.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-33, 2]}, {19.5, -16.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-33, 2]}, {20.5, -16.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-33, 2]}, {21.5, -16.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-33, 2]}, {22.5, -16.5}]], 
    RectangleBox[NCache[{Rational[47, 2], Rational[-33, 2]}, {23.5, -16.5}]], 
    RectangleBox[NCache[{Rational[49, 2], Rational[-33, 2]}, {24.5, -16.5}]], 
    RectangleBox[NCache[{Rational[3, 2], Rational[-35, 2]}, {1.5, -17.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-35, 2]}, {2.5, -17.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-35, 2]}, {3.5, -17.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-35, 2]}, {4.5, -17.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-35, 2]}, {5.5, -17.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-35, 2]}, {6.5, -17.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-35, 2]}, {7.5, -17.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-35, 2]}, {8.5, -17.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-35, 2]}, {9.5, -17.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-35, 2]}, {10.5, -17.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-35, 2]}, {11.5, -17.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-35, 2]}, {12.5, -17.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-35, 2]}, {13.5, -17.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-35, 2]}, {14.5, -17.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-35, 2]}, {15.5, -17.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-35, 2]}, {16.5, -17.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-35, 2]}, {17.5, -17.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-35, 2]}, {18.5, -17.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-35, 2]}, {19.5, -17.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-35, 2]}, {20.5, -17.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-35, 2]}, {21.5, -17.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-35, 2]}, {22.5, -17.5}]], 
    RectangleBox[NCache[{Rational[47, 2], Rational[-35, 2]}, {23.5, -17.5}]], 
    RectangleBox[NCache[{Rational[49, 2], Rational[-35, 2]}, {24.5, -17.5}]], 
    RectangleBox[NCache[{Rational[3, 2], Rational[-37, 2]}, {1.5, -18.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-37, 2]}, {2.5, -18.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-37, 2]}, {3.5, -18.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-37, 2]}, {4.5, -18.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-37, 2]}, {5.5, -18.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-37, 2]}, {6.5, -18.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-37, 2]}, {7.5, -18.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-37, 2]}, {8.5, -18.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-37, 2]}, {9.5, -18.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-37, 2]}, {10.5, -18.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-37, 2]}, {11.5, -18.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-37, 2]}, {12.5, -18.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-37, 2]}, {13.5, -18.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-37, 2]}, {14.5, -18.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-37, 2]}, {15.5, -18.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-37, 2]}, {16.5, -18.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-37, 2]}, {17.5, -18.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-37, 2]}, {18.5, -18.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-37, 2]}, {19.5, -18.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-37, 2]}, {20.5, -18.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-37, 2]}, {21.5, -18.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-37, 2]}, {22.5, -18.5}]], 
    RectangleBox[NCache[{Rational[47, 2], Rational[-37, 2]}, {23.5, -18.5}]], 
    RectangleBox[NCache[{Rational[49, 2], Rational[-37, 2]}, {24.5, -18.5}]], 
    RectangleBox[NCache[{Rational[3, 2], Rational[-39, 2]}, {1.5, -19.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-39, 2]}, {2.5, -19.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-39, 2]}, {3.5, -19.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-39, 2]}, {4.5, -19.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-39, 2]}, {5.5, -19.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-39, 2]}, {6.5, -19.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-39, 2]}, {7.5, -19.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-39, 2]}, {8.5, -19.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-39, 2]}, {9.5, -19.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-39, 2]}, {10.5, -19.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-39, 2]}, {11.5, -19.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-39, 2]}, {12.5, -19.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-39, 2]}, {13.5, -19.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-39, 2]}, {14.5, -19.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-39, 2]}, {15.5, -19.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-39, 2]}, {16.5, -19.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-39, 2]}, {17.5, -19.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-39, 2]}, {18.5, -19.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-39, 2]}, {19.5, -19.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-39, 2]}, {20.5, -19.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-39, 2]}, {21.5, -19.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-39, 2]}, {22.5, -19.5}]], 
    RectangleBox[NCache[{Rational[47, 2], Rational[-39, 2]}, {23.5, -19.5}]], 
    RectangleBox[NCache[{Rational[49, 2], Rational[-39, 2]}, {24.5, -19.5}]], 
    RectangleBox[NCache[{Rational[3, 2], Rational[-41, 2]}, {1.5, -20.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-41, 2]}, {2.5, -20.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-41, 2]}, {3.5, -20.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-41, 2]}, {4.5, -20.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-41, 2]}, {5.5, -20.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-41, 2]}, {6.5, -20.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-41, 2]}, {7.5, -20.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-41, 2]}, {8.5, -20.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-41, 2]}, {9.5, -20.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-41, 2]}, {10.5, -20.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-41, 2]}, {11.5, -20.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-41, 2]}, {12.5, -20.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-41, 2]}, {13.5, -20.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-41, 2]}, {14.5, -20.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-41, 2]}, {15.5, -20.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-41, 2]}, {16.5, -20.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-41, 2]}, {17.5, -20.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-41, 2]}, {18.5, -20.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-41, 2]}, {19.5, -20.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-41, 2]}, {20.5, -20.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-41, 2]}, {21.5, -20.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-41, 2]}, {22.5, -20.5}]], 
    RectangleBox[NCache[{Rational[47, 2], Rational[-41, 2]}, {23.5, -20.5}]], 
    RectangleBox[NCache[{Rational[49, 2], Rational[-41, 2]}, {24.5, -20.5}]], 
    RectangleBox[NCache[{Rational[3, 2], Rational[-43, 2]}, {1.5, -21.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-43, 2]}, {2.5, -21.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-43, 2]}, {3.5, -21.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-43, 2]}, {4.5, -21.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-43, 2]}, {5.5, -21.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-43, 2]}, {6.5, -21.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-43, 2]}, {7.5, -21.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-43, 2]}, {8.5, -21.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-43, 2]}, {9.5, -21.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-43, 2]}, {10.5, -21.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-43, 2]}, {11.5, -21.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-43, 2]}, {12.5, -21.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-43, 2]}, {13.5, -21.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-43, 2]}, {14.5, -21.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-43, 2]}, {15.5, -21.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-43, 2]}, {16.5, -21.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-43, 2]}, {17.5, -21.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-43, 2]}, {18.5, -21.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-43, 2]}, {19.5, -21.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-43, 2]}, {20.5, -21.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-43, 2]}, {21.5, -21.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-43, 2]}, {22.5, -21.5}]], 
    RectangleBox[NCache[{Rational[47, 2], Rational[-43, 2]}, {23.5, -21.5}]], 
    RectangleBox[NCache[{Rational[49, 2], Rational[-43, 2]}, {24.5, -21.5}]], 
    RectangleBox[NCache[{Rational[3, 2], Rational[-45, 2]}, {1.5, -22.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-45, 2]}, {2.5, -22.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-45, 2]}, {3.5, -22.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-45, 2]}, {4.5, -22.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-45, 2]}, {5.5, -22.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-45, 2]}, {6.5, -22.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-45, 2]}, {7.5, -22.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-45, 2]}, {8.5, -22.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-45, 2]}, {9.5, -22.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-45, 2]}, {10.5, -22.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-45, 2]}, {11.5, -22.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-45, 2]}, {12.5, -22.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-45, 2]}, {13.5, -22.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-45, 2]}, {14.5, -22.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-45, 2]}, {15.5, -22.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-45, 2]}, {16.5, -22.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-45, 2]}, {17.5, -22.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-45, 2]}, {18.5, -22.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-45, 2]}, {19.5, -22.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-45, 2]}, {20.5, -22.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-45, 2]}, {21.5, -22.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-45, 2]}, {22.5, -22.5}]], 
    RectangleBox[NCache[{Rational[47, 2], Rational[-45, 2]}, {23.5, -22.5}]], 
    RectangleBox[NCache[{Rational[49, 2], Rational[-45, 2]}, {24.5, -22.5}]], 
    RectangleBox[NCache[{Rational[3, 2], Rational[-47, 2]}, {1.5, -23.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-47, 2]}, {2.5, -23.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-47, 2]}, {3.5, -23.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-47, 2]}, {4.5, -23.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-47, 2]}, {5.5, -23.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-47, 2]}, {6.5, -23.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-47, 2]}, {7.5, -23.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-47, 2]}, {8.5, -23.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-47, 2]}, {9.5, -23.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-47, 2]}, {10.5, -23.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-47, 2]}, {11.5, -23.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-47, 2]}, {12.5, -23.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-47, 2]}, {13.5, -23.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-47, 2]}, {14.5, -23.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-47, 2]}, {15.5, -23.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-47, 2]}, {16.5, -23.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-47, 2]}, {17.5, -23.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-47, 2]}, {18.5, -23.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-47, 2]}, {19.5, -23.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-47, 2]}, {20.5, -23.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-47, 2]}, {21.5, -23.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-47, 2]}, {22.5, -23.5}]], 
    RectangleBox[NCache[{Rational[47, 2], Rational[-47, 2]}, {23.5, -23.5}]], 
    RectangleBox[NCache[{Rational[49, 2], Rational[-47, 2]}, {24.5, -23.5}]], 
    RectangleBox[NCache[{Rational[3, 2], Rational[-49, 2]}, {1.5, -24.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-49, 2]}, {2.5, -24.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-49, 2]}, {3.5, -24.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-49, 2]}, {4.5, -24.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-49, 2]}, {5.5, -24.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-49, 2]}, {6.5, -24.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-49, 2]}, {7.5, -24.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-49, 2]}, {8.5, -24.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-49, 2]}, {9.5, -24.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-49, 2]}, {10.5, -24.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-49, 2]}, {11.5, -24.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-49, 2]}, {12.5, -24.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-49, 2]}, {13.5, -24.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-49, 2]}, {14.5, -24.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-49, 2]}, {15.5, -24.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-49, 2]}, {16.5, -24.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-49, 2]}, {17.5, -24.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-49, 2]}, {18.5, -24.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-49, 2]}, {19.5, -24.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-49, 2]}, {20.5, -24.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-49, 2]}, {21.5, -24.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-49, 2]}, {22.5, -24.5}]], 
    RectangleBox[NCache[{Rational[47, 2], Rational[-49, 2]}, {23.5, -24.5}]], 
    RectangleBox[NCache[{Rational[49, 2], Rational[-49, 2]}, {24.5, -24.5}]], 
    RectangleBox[NCache[{Rational[3, 2], Rational[-51, 2]}, {1.5, -25.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-51, 2]}, {2.5, -25.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-51, 2]}, {3.5, -25.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-51, 2]}, {4.5, -25.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-51, 2]}, {5.5, -25.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-51, 2]}, {6.5, -25.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-51, 2]}, {7.5, -25.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-51, 2]}, {8.5, -25.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-51, 2]}, {9.5, -25.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-51, 2]}, {10.5, -25.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-51, 2]}, {11.5, -25.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-51, 2]}, {12.5, -25.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-51, 2]}, {13.5, -25.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-51, 2]}, {14.5, -25.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-51, 2]}, {15.5, -25.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-51, 2]}, {16.5, -25.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-51, 2]}, {17.5, -25.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-51, 2]}, {18.5, -25.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-51, 2]}, {19.5, -25.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-51, 2]}, {20.5, -25.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-51, 2]}, {21.5, -25.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-51, 2]}, {22.5, -25.5}]], 
    RectangleBox[NCache[{Rational[47, 2], Rational[-51, 2]}, {23.5, -25.5}]], 
    RectangleBox[NCache[{Rational[49, 2], Rational[-51, 2]}, {24.5, -25.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-53, 2]}, {2.5, -26.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-53, 2]}, {3.5, -26.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-53, 2]}, {4.5, -26.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-53, 2]}, {5.5, -26.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-53, 2]}, {6.5, -26.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-53, 2]}, {7.5, -26.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-53, 2]}, {8.5, -26.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-53, 2]}, {9.5, -26.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-53, 2]}, {10.5, -26.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-53, 2]}, {11.5, -26.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-53, 2]}, {12.5, -26.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-53, 2]}, {13.5, -26.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-53, 2]}, {14.5, -26.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-53, 2]}, {15.5, -26.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-53, 2]}, {16.5, -26.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-53, 2]}, {17.5, -26.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-53, 2]}, {18.5, -26.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-53, 2]}, {19.5, -26.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-53, 2]}, {20.5, -26.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-53, 2]}, {21.5, -26.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-53, 2]}, {22.5, -26.5}]], 
    RectangleBox[NCache[{Rational[47, 2], Rational[-53, 2]}, {23.5, -26.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-55, 2]}, {2.5, -27.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-55, 2]}, {3.5, -27.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-55, 2]}, {4.5, -27.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-55, 2]}, {5.5, -27.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-55, 2]}, {6.5, -27.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-55, 2]}, {7.5, -27.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-55, 2]}, {8.5, -27.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-55, 2]}, {9.5, -27.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-55, 2]}, {10.5, -27.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-55, 2]}, {11.5, -27.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-55, 2]}, {12.5, -27.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-55, 2]}, {13.5, -27.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-55, 2]}, {14.5, -27.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-55, 2]}, {15.5, -27.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-55, 2]}, {16.5, -27.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-55, 2]}, {17.5, -27.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-55, 2]}, {18.5, -27.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-55, 2]}, {19.5, -27.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-55, 2]}, {20.5, -27.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-55, 2]}, {21.5, -27.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-55, 2]}, {22.5, -27.5}]], 
    RectangleBox[NCache[{Rational[47, 2], Rational[-55, 2]}, {23.5, -27.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-57, 2]}, {3.5, -28.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-57, 2]}, {4.5, -28.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-57, 2]}, {5.5, -28.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-57, 2]}, {6.5, -28.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-57, 2]}, {7.5, -28.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-57, 2]}, {8.5, -28.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-57, 2]}, {9.5, -28.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-57, 2]}, {10.5, -28.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-57, 2]}, {11.5, -28.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-57, 2]}, {12.5, -28.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-57, 2]}, {13.5, -28.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-57, 2]}, {14.5, -28.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-57, 2]}, {15.5, -28.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-57, 2]}, {16.5, -28.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-57, 2]}, {17.5, -28.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-57, 2]}, {18.5, -28.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-57, 2]}, {19.5, -28.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-57, 2]}, {20.5, -28.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-57, 2]}, {21.5, -28.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-57, 2]}, {22.5, -28.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-59, 2]}, {4.5, -29.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-59, 2]}, {5.5, -29.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-59, 2]}, {6.5, -29.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-59, 2]}, {7.5, -29.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-59, 2]}, {8.5, -29.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-59, 2]}, {9.5, -29.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-59, 2]}, {10.5, -29.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-59, 2]}, {11.5, -29.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-59, 2]}, {12.5, -29.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-59, 2]}, {13.5, -29.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-59, 2]}, {14.5, -29.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-59, 2]}, {15.5, -29.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-59, 2]}, {16.5, -29.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-59, 2]}, {17.5, -29.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-59, 2]}, {18.5, -29.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-59, 2]}, {19.5, -29.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-59, 2]}, {20.5, -29.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-59, 2]}, {21.5, -29.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-61, 2]}, {5.5, -30.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-61, 2]}, {6.5, -30.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-61, 2]}, {7.5, -30.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-61, 2]}, {8.5, -30.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-61, 2]}, {9.5, -30.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-61, 2]}, {10.5, -30.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-61, 2]}, {11.5, -30.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-61, 2]}, {12.5, -30.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-61, 2]}, {13.5, -30.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-61, 2]}, {14.5, -30.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-61, 2]}, {15.5, -30.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-61, 2]}, {16.5, -30.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-61, 2]}, {17.5, -30.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-61, 2]}, {18.5, -30.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-61, 2]}, {19.5, -30.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-61, 2]}, {20.5, -30.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-63, 2]}, {6.5, -31.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-63, 2]}, {7.5, -31.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-63, 2]}, {8.5, -31.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-63, 2]}, {9.5, -31.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-63, 2]}, {10.5, -31.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-63, 2]}, {11.5, -31.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-63, 2]}, {12.5, -31.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-63, 2]}, {13.5, -31.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-63, 2]}, {14.5, -31.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-63, 2]}, {15.5, -31.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-63, 2]}, {16.5, -31.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-63, 2]}, {17.5, -31.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-63, 2]}, {18.5, -31.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-63, 2]}, {19.5, -31.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-65, 2]}, {8.5, -32.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-65, 2]}, {9.5, -32.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-65, 2]}, {10.5, -32.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-65, 2]}, {11.5, -32.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-65, 2]}, {12.5, -32.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-65, 2]}, {13.5, -32.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-65, 2]}, {14.5, -32.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-65, 2]}, {15.5, -32.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-65, 2]}, {16.5, -32.5}]], 
    RectangleBox[
     NCache[{Rational[35, 2], Rational[-65, 2]}, {17.5, -32.5}]]}, {{}, 
    GraphicsComplexBox[CompressedData["
1:eJx1mTtu3EAQBdeOHDpQ4ECBTCwIYrFY7PxIrvmRzuAjGHDsK+owPohhqCsp
gEqERr3p6X7TpCjy+68/P39/Pp1Ofz+dTv9/x8/bx6/H+8fvLxEvET9FvEb8
NeIf0s/SP6RfpIez/yT9LP0ovTn1sJ56n8S/iT9HvEu/Sb9ID3854PTHevoj
f1O9JWL6yxHTXxXHD9ZP0jfpi/Tkox7yUS/+0g/+0S/+dRHj3/mAe73ze/8q
nsXvqv8aMf3fIqbfi9YPys966iM/9WfxKk799E9/fcT0P0S8iu/ibxFfI36N
+BLxJr6IM3/kYz7Yj/mg3iKexPGzixg/8aMX7yLG37P0g/T4z374Tz1ZvIrj
P/3iP37gP36t4rs4/t8jxv9bxJv4Io7/5MN/9sN/6i3iSRz/6Rf/8aMXx/8u
4rP0g/T4z374Tz1ZvIrjP/3iP37gP37hfzrgXu/8VTyLu373N4jjD/nwj3y9
OP5TL+eTxLN4iZjzrRFz/i3iJs78FHHys579yX8/4F7v/Mwv+zPf1LdJv0rP
9ZQP9FxP6UDP9VelZz35qGeXfpWe+SI/88X+zBd+VfEsznwxD8wX8zKIM1/k
Y77I16u+szj6dKCH0/9ZHD1+XKR3vkF68jXpi/Rw57+JM59TxHfxmzj+jtqP
/Bdx9OQjP/lcz1X8Iu79XI/7tX9Xcfebxav4KM78FnHOr4pncfZnnqiPeRvE
fX/spb9Ij7/sx3lTTxFv4tyP6Jf7UTvgTbyIe3/XdxHvI6afQfqr9PjJfvhN
PVV8FOc8mT/6fRzwSXwUb+JVvIhn8SROf3PEnv+b+F08iWfxIl7Fm/goPonP
4g9x/h7QL38vOA/+3rF+k95/D39IT75Z+lF6+EN8Fp/ER/EmXsWLeBZP4j5v
zvchPX5k8SJexZv4KD6Jz+IPcfxs4vSD//VA7+cF6zn/fKDn+SMd6Bdx6uP+
Sb/cX/GH54kinsQ5H55nuZ/xvNuL87zA8z/39056/l+4SM9+5Kce8hfxJk6/
1I8f9LeIb+J+fvT/a36efBVHf5M+Heh9ntav0jNf5Gd+6WcUr+JcT/jF9Yif
3H85j0Hc/+/5vHvpOV/243yph/Ol3iLexDlf/OB88YvzzQfc65t4EXd9rt/9
9eJ+HvfzziCO/9TD+dAP58f9oYqP4rM485PE2X8Ur+LsT/3UR7/Ujx+DOP0z
H/hzFu+0Hu759Px6vqv4KO7rx9fXKr6Lc72Tj+ub/TbxRZz5pB/mk36beBFn
PruImU/ehzGfvC/rI+b9Jv7y/vIqPf6SD3/Zr4qP4vhLvfhLP6v4Lo6/5MNf
9tvEF3H8pR/8pd8mXsTxF79u4vbX/vt8ingT9/l7PhbxTdzvc/GPedvFV3Gf
j89vFK/ing/Pj+drEOf6x99eer8f9vvjJF7E/X7a76/9fnsR38Txm3z4/SJO
P/hPP6s4/jNv+M/3Bn+voh++T9Av6zkf1nM+rE/i/v7h70XW36RP0t+lv0oP
p3/2w58qPorjD37jXxexv8dxnuTjvKnH3wv9vYt66I96We/vYfjBevplvf3w
9yT8pf4kXsSpFz/op4uYfpnXRXwT9/12l555f5ae+shHf+yHP/4+PL3/A4w+
k68=
     "], {{{}, {}, 
       {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwl1WN7GAYUBeCktu3Utm0ztdvUTG3btm3btm2384qhHdqte/Psw3vuLzjn
BoWEBncPDAgIeCPCbjjCE4GIRCIyUYhKNKITg5jEIjZxiEs84pOAhCQiMUlI
SjKSk4KUpCI1aQgiLelITwYykonMZCEr2chODnKSi9zkIS/5yE8BClKIwhSh
KMUoTglKUorSlKEs5ShPBSpSicpUoSrVqE4NalKL2tQhmLrUoz4NaEgjGtOE
pjSjOS1oSStaE0Ib2tKO9nSgI53oTBe60o3uhNKDnvSiN33oSz/6M4CBDGIw
QxjKMIYzgpGMYjRjGMs4xjOBiUxiMlOYyjSmM4OZzGI2c5jLPOazgIUsYjFL
WMoylrOClaxiNWtYyzrWs4GNbGIzW9jKNrazg53sYjd72Ms+9nOAgxziMEc4
yjGOc4KTnOI0ZzjLOc5zgYtc4jJXuMo1rnODm9ziNne4yz3u84CHPOIxT3jK
M57zgpe84jVv+IZv+Y7v+YEf+Ymfecs73vOBX/iV3/idj3ziD/7kL/7mM1/4
h3/5Slj5AwlHeCIQkUhEJgpRiUZ0YhCTWMQmDnGJR3wSkJBEJCYJSUlGclKQ
klSkJg1BpCUd6clARjKRmSxkJRvZyUFOcpGbPOQlH/kpQEEKUZgiFKUYxSlB
SUpRmjKUpRzlqUBFKlGZKlSlGtWpQU1qUZs6BFOXetSnAQ1pRGOa0JRmNKcF
LWlFa0JoQ1va0Z4OdKQTnelCV7oRNt6h9KAnvehNH/rSj/4MYCCDGMwQhjKM
4YxgJKMYzRjGMo7xTGAik5jMFKYyjenMYCazmM0c5jKP+SxgIYtYzBKWsozl
rGAlq1jNGtayjvVsYCOb2MwWtrKN7exgJ7vYzR72so/9HOAghzjMEY5yjOOc
4CSnOM0ZznKO81zgIpe4zBWuco3r3OAmt7jNHe5yj/s84CGPeMwTnvKM57zg
Ja94Hfj/P/4Pi1no+A==
         "]]}}, {
       {RGBColor[0.24720000000000014`, 0.24, 0.6], PointBox[CompressedData["
1:eJwl1WN7GAYUBeCktu3Utm0ztdvUTG3btm3btm2384qhHdqte/Psw3vuLzjn
BoWEBncPDAgIeCPCbjjCE4GIRCIyUYhKNKITg5jEIjZxiEs84pOAhCQiMUlI
SjKSk4KUpCI1aQgiLelITwYykonMZCEr2chODnKSi9zkIS/5yE8BClKIwhSh
KMUoTglKUorSlKEs5ShPBSpSicpUoSrVqE4NalKL2tQhmLrUoz4NaEgjGtOE
pjSjOS1oSStaE0Ib2tKO9nSgI53oTBe60o3uhNKDnvSiN33oSz/6M4CBDGIw
QxjKMIYzgpGMYjRjGMs4xjOBiUxiMlOYyjSmM4OZzGI2c5jLPOazgIUsYjFL
WMoylrOClaxiNWtYyzrWs4GNbGIzW9jKNrazg53sYjd72Ms+9nOAgxziMEc4
yjGOc4KTnOI0ZzjLOc5zgYtc4jJXuMo1rnODm9ziNne4yz3u84CHPOIxT3jK
M57zgpe84jVv+IZv+Y7v+YEf+Ymfecs73vOBX/iV3/idj3ziD/7kL/7mM1/4
h3/5Slj5AwlHeCIQkUhEJgpRiUZ0YhCTWMQmDnGJR3wSkJBEJCYJSUlGclKQ
klSkJg1BpCUd6clARjKRmSxkJRvZyUFOcpGbPOQlH/kpQEEKUZgiFKUYxSlB
SUpRmjKUpRzlqUBFKlGZKlSlGtWpQU1qUZs6BFOXetSnAQ1pRGOa0JRmNKcF
LWlFa0JoQ1va0Z4OdKQTnelCV7oRNt6h9KAnvehNH/rSj/4MYCCDGMwQhjKM
4YxgJKMYzRjGMo7xTGAik5jMFKYyjenMYCazmM0c5jKP+SxgIYtYzBKWsozl
rGAlq1jNGtayjvVsYCOb2MwWtrKN7exgJ7vYzR72so/9HOAghzjMEY5yjOOc
4CSnOM0ZznKO81zgIpe4zBWuco3r3OAmt7jNHe5yj/s84CGPeMwTnvKM57zg
Ja94Hfj/P/4Pi1no+A==
         "]]}, {}, {}}}], {}}},
  ImageSize->{492.51953125, Automatic}]], "Output",
 CellLabel->"Out[30]="]
}, Open  ]],

Cell["\<\
Playing around with other characters is amusing for a while. Here is the \
letter \[OpenCurlyDoubleQuote]o\[CloseCurlyDoubleQuote] in 34 point...\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"showImageTour", "[", 
  RowBox[{"Style", "[", 
   RowBox[{"\"\<o\>\"", ",", "34"}], "]"}], "]"}]], "Input",
 CellLabel->"In[31]:="],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0.7], EdgeForm[GrayLevel[0]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-23, 2]}, {6.5, -11.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-23, 2]}, {7.5, -11.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-23, 2]}, {8.5, -11.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-23, 2]}, {9.5, -11.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-23, 2]}, {10.5, -11.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-23, 2]}, {11.5, -11.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-23, 2]}, {12.5, -11.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-23, 2]}, {13.5, -11.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-25, 2]}, {5.5, -12.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-25, 2]}, {6.5, -12.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-25, 2]}, {7.5, -12.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-25, 2]}, {8.5, -12.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-25, 2]}, {9.5, -12.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-25, 2]}, {10.5, -12.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-25, 2]}, {11.5, -12.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-25, 2]}, {12.5, -12.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-25, 2]}, {13.5, -12.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-25, 2]}, {14.5, -12.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-25, 2]}, {15.5, -12.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-27, 2]}, {3.5, -13.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-27, 2]}, {4.5, -13.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-27, 2]}, {5.5, -13.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-27, 2]}, {6.5, -13.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-27, 2]}, {7.5, -13.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-27, 2]}, {8.5, -13.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-27, 2]}, {11.5, -13.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-27, 2]}, {12.5, -13.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-27, 2]}, {13.5, -13.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-27, 2]}, {14.5, -13.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-27, 2]}, {15.5, -13.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-27, 2]}, {16.5, -13.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-29, 2]}, {3.5, -14.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-29, 2]}, {4.5, -14.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-29, 2]}, {5.5, -14.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-29, 2]}, {6.5, -14.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-29, 2]}, {13.5, -14.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-29, 2]}, {14.5, -14.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-29, 2]}, {15.5, -14.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-29, 2]}, {16.5, -14.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-29, 2]}, {17.5, -14.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-31, 2]}, {2.5, -15.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-31, 2]}, {3.5, -15.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-31, 2]}, {4.5, -15.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-31, 2]}, {5.5, -15.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-31, 2]}, {15.5, -15.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-31, 2]}, {16.5, -15.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-31, 2]}, {17.5, -15.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-33, 2]}, {2.5, -16.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-33, 2]}, {3.5, -16.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-33, 2]}, {4.5, -16.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-33, 2]}, {15.5, -16.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-33, 2]}, {16.5, -16.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-33, 2]}, {17.5, -16.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-33, 2]}, {18.5, -16.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-35, 2]}, {2.5, -17.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-35, 2]}, {3.5, -17.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-35, 2]}, {4.5, -17.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-35, 2]}, {16.5, -17.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-35, 2]}, {17.5, -17.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-35, 2]}, {18.5, -17.5}]], 
    RectangleBox[NCache[{Rational[3, 2], Rational[-37, 2]}, {1.5, -18.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-37, 2]}, {2.5, -18.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-37, 2]}, {3.5, -18.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-37, 2]}, {4.5, -18.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-37, 2]}, {16.5, -18.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-37, 2]}, {17.5, -18.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-37, 2]}, {18.5, -18.5}]], 
    RectangleBox[NCache[{Rational[3, 2], Rational[-39, 2]}, {1.5, -19.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-39, 2]}, {2.5, -19.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-39, 2]}, {3.5, -19.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-39, 2]}, {4.5, -19.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-39, 2]}, {16.5, -19.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-39, 2]}, {17.5, -19.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-39, 2]}, {18.5, -19.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-41, 2]}, {2.5, -20.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-41, 2]}, {3.5, -20.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-41, 2]}, {4.5, -20.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-41, 2]}, {16.5, -20.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-41, 2]}, {17.5, -20.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-41, 2]}, {18.5, -20.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-43, 2]}, {2.5, -21.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-43, 2]}, {3.5, -21.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-43, 2]}, {4.5, -21.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-43, 2]}, {15.5, -21.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-43, 2]}, {16.5, -21.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-43, 2]}, {17.5, -21.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-43, 2]}, {18.5, -21.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-45, 2]}, {2.5, -22.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-45, 2]}, {3.5, -22.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-45, 2]}, {4.5, -22.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-45, 2]}, {5.5, -22.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-45, 2]}, {15.5, -22.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-45, 2]}, {16.5, -22.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-45, 2]}, {17.5, -22.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-45, 2]}, {18.5, -22.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-47, 2]}, {3.5, -23.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-47, 2]}, {4.5, -23.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-47, 2]}, {5.5, -23.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-47, 2]}, {6.5, -23.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-47, 2]}, {14.5, -23.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-47, 2]}, {15.5, -23.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-47, 2]}, {16.5, -23.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-47, 2]}, {17.5, -23.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-49, 2]}, {3.5, -24.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-49, 2]}, {4.5, -24.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-49, 2]}, {5.5, -24.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-49, 2]}, {6.5, -24.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-49, 2]}, {7.5, -24.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-49, 2]}, {8.5, -24.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-49, 2]}, {12.5, -24.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-49, 2]}, {13.5, -24.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-49, 2]}, {14.5, -24.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-49, 2]}, {15.5, -24.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-49, 2]}, {16.5, -24.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-51, 2]}, {4.5, -25.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-51, 2]}, {5.5, -25.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-51, 2]}, {6.5, -25.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-51, 2]}, {7.5, -25.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-51, 2]}, {8.5, -25.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-51, 2]}, {9.5, -25.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-51, 2]}, {10.5, -25.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-51, 2]}, {11.5, -25.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-51, 2]}, {12.5, -25.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-51, 2]}, {13.5, -25.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-51, 2]}, {14.5, -25.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-51, 2]}, {15.5, -25.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-53, 2]}, {6.5, -26.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-53, 2]}, {7.5, -26.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-53, 2]}, {8.5, -26.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-53, 2]}, {9.5, -26.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-53, 2]}, {10.5, -26.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-53, 2]}, {11.5, -26.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-53, 2]}, {12.5, -26.5}]], 
    RectangleBox[
     NCache[{Rational[27, 2], Rational[-53, 2]}, {13.5, -26.5}]]}, {{}, 
    GraphicsComplexBox[CompressedData["
1:eJx1ljtqw0AUAEWqlC5SuHChCCHEsizWP3KVM+QIgdS5Rc7loyXBb5oBGYx4
zLyPn9eSXz+/P76eqqr6+Xv/X+P1/rhM98f1OeIh4peIx4hPEV/Fc8SXiFPE
54iLfPjpgNOfeUZx5iV/Ed/Uf5f/Jn8Vn9V/lb/I38Tpxz5umof+9YHvevjk
r/Lhjep16p/Ei/Kvqj+I4+/ymXc8yJ/F+T4ncXy+X+qzb/pv8ulHfepN4viL
/Em+Of2Yh33kiNlHH7H3bf8mn/xWvFF+LY6/i/u8MP9FPvWp14knceb3ecFn
vz4P7JP9TuL83qnH/YV6Pi/45Bf53F84L1kcn3ruN4jTf5TPvEXc/ezDma+P
OIvjJ3H8Xrw94F3ESX4Wxye/Fa/FOU/MexbHJ79R/05+kp/lX+WzX+8TP8mn
n+fx54Ezf5IPxyefz888PB/I535e5Pt5mOVzfngeFfl+XvL7In+Wv8o3H8Xp
X4nj+//Dcv8F1Duz+w==
     "], {{{}, {}, 
       {RGBColor[0.24720000000000014`, 0.24, 0.6], 
        LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
         18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
         35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
         52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
         69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 
         86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 
         102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115,
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
         129, 130, 131, 132, 133, 134}]}}, {
       {RGBColor[0.24720000000000014`, 0.24, 0.6], 
        PointBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
         18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
         35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
         52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
         69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 
         86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 
         102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115,
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
         129, 130, 131, 132, 133, 134}]}, {}, {}}}], {}}}]], "Output",
 CellLabel->"Out[31]="]
}, Open  ]],

Cell["An asterisk at 52 point", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"showImageTour", "[", 
  RowBox[{"Style", "[", 
   RowBox[{"\"\<*\>\"", ",", "52"}], "]"}], "]"}]], "Input",
 CellLabel->"In[32]:="],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0.7], EdgeForm[GrayLevel[0]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-39, 2]}, {14.5, -19.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-39, 2]}, {15.5, -19.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-39, 2]}, {16.5, -19.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-41, 2]}, {14.5, -20.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-41, 2]}, {15.5, -20.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-41, 2]}, {16.5, -20.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-43, 2]}, {14.5, -21.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-43, 2]}, {15.5, -21.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-43, 2]}, {16.5, -21.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-45, 2]}, {14.5, -22.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-45, 2]}, {15.5, -22.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-45, 2]}, {16.5, -22.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-47, 2]}, {14.5, -23.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-47, 2]}, {15.5, -23.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-47, 2]}, {16.5, -23.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-49, 2]}, {7.5, -24.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-49, 2]}, {14.5, -24.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-49, 2]}, {15.5, -24.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-49, 2]}, {16.5, -24.5}]], 
    RectangleBox[NCache[{Rational[47, 2], Rational[-49, 2]}, {23.5, -24.5}]], 
    RectangleBox[NCache[{Rational[49, 2], Rational[-49, 2]}, {24.5, -24.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-51, 2]}, {6.5, -25.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-51, 2]}, {7.5, -25.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-51, 2]}, {8.5, -25.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-51, 2]}, {9.5, -25.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-51, 2]}, {10.5, -25.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-51, 2]}, {14.5, -25.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-51, 2]}, {15.5, -25.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-51, 2]}, {16.5, -25.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-51, 2]}, {21.5, -25.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-51, 2]}, {22.5, -25.5}]], 
    RectangleBox[NCache[{Rational[47, 2], Rational[-51, 2]}, {23.5, -25.5}]], 
    RectangleBox[NCache[{Rational[49, 2], Rational[-51, 2]}, {24.5, -25.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-53, 2]}, {6.5, -26.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-53, 2]}, {7.5, -26.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-53, 2]}, {8.5, -26.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-53, 2]}, {9.5, -26.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-53, 2]}, {10.5, -26.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-53, 2]}, {11.5, -26.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-53, 2]}, {12.5, -26.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-53, 2]}, {14.5, -26.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-53, 2]}, {15.5, -26.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-53, 2]}, {16.5, -26.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-53, 2]}, {18.5, -26.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-53, 2]}, {19.5, -26.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-53, 2]}, {20.5, -26.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-53, 2]}, {21.5, -26.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-53, 2]}, {22.5, -26.5}]], 
    RectangleBox[NCache[{Rational[47, 2], Rational[-53, 2]}, {23.5, -26.5}]], 
    RectangleBox[NCache[{Rational[49, 2], Rational[-53, 2]}, {24.5, -26.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-55, 2]}, {7.5, -27.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-55, 2]}, {8.5, -27.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-55, 2]}, {9.5, -27.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-55, 2]}, {10.5, -27.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-55, 2]}, {11.5, -27.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-55, 2]}, {12.5, -27.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-55, 2]}, {13.5, -27.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-55, 2]}, {14.5, -27.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-55, 2]}, {15.5, -27.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-55, 2]}, {16.5, -27.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-55, 2]}, {17.5, -27.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-55, 2]}, {18.5, -27.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-55, 2]}, {19.5, -27.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-55, 2]}, {20.5, -27.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-55, 2]}, {21.5, -27.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-55, 2]}, {22.5, -27.5}]], 
    RectangleBox[NCache[{Rational[47, 2], Rational[-55, 2]}, {23.5, -27.5}]], 
    RectangleBox[NCache[{Rational[49, 2], Rational[-55, 2]}, {24.5, -27.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-57, 2]}, {10.5, -28.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-57, 2]}, {11.5, -28.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-57, 2]}, {12.5, -28.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-57, 2]}, {13.5, -28.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-57, 2]}, {14.5, -28.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-57, 2]}, {15.5, -28.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-57, 2]}, {16.5, -28.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-57, 2]}, {17.5, -28.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-57, 2]}, {18.5, -28.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-57, 2]}, {19.5, -28.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-57, 2]}, {20.5, -28.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-59, 2]}, {13.5, -29.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-59, 2]}, {14.5, -29.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-59, 2]}, {15.5, -29.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-59, 2]}, {16.5, -29.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-59, 2]}, {17.5, -29.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-61, 2]}, {13.5, -30.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-61, 2]}, {14.5, -30.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-61, 2]}, {15.5, -30.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-61, 2]}, {16.5, -30.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-61, 2]}, {17.5, -30.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-61, 2]}, {18.5, -30.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-63, 2]}, {12.5, -31.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-63, 2]}, {13.5, -31.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-63, 2]}, {14.5, -31.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-63, 2]}, {15.5, -31.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-63, 2]}, {16.5, -31.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-63, 2]}, {17.5, -31.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-63, 2]}, {18.5, -31.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-63, 2]}, {19.5, -31.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-65, 2]}, {11.5, -32.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-65, 2]}, {12.5, -32.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-65, 2]}, {13.5, -32.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-65, 2]}, {14.5, -32.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-65, 2]}, {17.5, -32.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-65, 2]}, {18.5, -32.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-65, 2]}, {19.5, -32.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-67, 2]}, {10.5, -33.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-67, 2]}, {11.5, -33.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-67, 2]}, {12.5, -33.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-67, 2]}, {13.5, -33.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-67, 2]}, {17.5, -33.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-67, 2]}, {18.5, -33.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-67, 2]}, {19.5, -33.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-67, 2]}, {20.5, -33.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-69, 2]}, {9.5, -34.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-69, 2]}, {10.5, -34.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-69, 2]}, {11.5, -34.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-69, 2]}, {12.5, -34.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-69, 2]}, {18.5, -34.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-69, 2]}, {19.5, -34.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-69, 2]}, {20.5, -34.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-69, 2]}, {21.5, -34.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-71, 2]}, {9.5, -35.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-71, 2]}, {10.5, -35.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-71, 2]}, {11.5, -35.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-71, 2]}, {12.5, -35.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-71, 2]}, {19.5, -35.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-71, 2]}, {20.5, -35.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-71, 2]}, {21.5, -35.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-71, 2]}, {22.5, -35.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-73, 2]}, {10.5, -36.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-73, 2]}, {11.5, -36.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-73, 2]}, {19.5, -36.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-73, 2]}, {20.5, -36.5}]], 
    RectangleBox[
     NCache[{Rational[43, 2], Rational[-73, 2]}, {21.5, -36.5}]]}, {{}, 
    GraphicsComplexBox[CompressedData["
1:eJx1ll1qg0AURqXr6IMNEkRKiB1/xvgTkyVkCYU+dws+dV0uLSneb8CDBoJc
zpk7d2auk3x8/z5+3qIo+nt9/5/L531cnpd5eR4sbiyOLW7ntd/A1/gjeIrx
CfwY/gG+8nUWZztc+dIdn/W14PI/LR4sPlk8wr/C7+GDTxqv+sY1D34GX/Xe
wG/gd4sT+Om2P3E9rE9+gvHimi+Df9z2J65XsfZrAO/AdX5ni73FucUVeIHx
FfwanPnUj18Wq1+UvwPX+RfgJeqvkc9jvgZc/gVcvodfwS/AVa/q03p68AH8
Cq7zy+G7bT+cv+oZ1zz4bscXL7d56Det/772Q3/W8Ev4FXzlH9d+GO+2feab
yDme+4n9CPsr3oN34C24+qEE13rZT3of1G/sX/arfA9f+TVfAa56VL+Dn8M/
gas/G3C93xrv4fM+4H3h4JfwHfwCXP55xyfnfdSAt+A6f83H95m/X+TaT923
yp+CJ+DxDuf/BT8/AQplx+4=
     "], {{{}, {}, 
       {RGBColor[0.24720000000000014`, 0.24, 0.6], 
        LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
         18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
         35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
         52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
         69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 
         86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 
         102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115,
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
         129, 130, 131, 132, 133, 134}]}}, {
       {RGBColor[0.24720000000000014`, 0.24, 0.6], 
        PointBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
         18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
         35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
         52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
         69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 
         86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 
         102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115,
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
         129, 130, 131, 132, 133, 134}]}, {}, {}}}], {}}}]], "Output",
 CellLabel->"Out[32]="]
}, Open  ]],

Cell["\<\
And since chess puts us firmly in the \[OpenCurlyDoubleQuote]games\
\[CloseCurlyDoubleQuote] space, here are some playing card suits...\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"showImageTour", "[", 
  RowBox[{"Style", "[", 
   RowBox[{"\"\<\[ClubSuit]\>\"", ",", "35"}], "]"}], "]"}]], "Input",
 CellLabel->"In[33]:="],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0.7], EdgeForm[GrayLevel[0]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-15, 2]}, {9.5, -7.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-15, 2]}, {10.5, -7.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-15, 2]}, {11.5, -7.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-17, 2]}, {7.5, -8.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-17, 2]}, {8.5, -8.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-17, 2]}, {9.5, -8.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-17, 2]}, {10.5, -8.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-17, 2]}, {11.5, -8.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-17, 2]}, {12.5, -8.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-17, 2]}, {13.5, -8.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-19, 2]}, {7.5, -9.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-19, 2]}, {8.5, -9.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-19, 2]}, {9.5, -9.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-19, 2]}, {10.5, -9.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-19, 2]}, {11.5, -9.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-19, 2]}, {12.5, -9.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-19, 2]}, {13.5, -9.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-19, 2]}, {14.5, -9.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-21, 2]}, {6.5, -10.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-21, 2]}, {7.5, -10.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-21, 2]}, {8.5, -10.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-21, 2]}, {9.5, -10.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-21, 2]}, {10.5, -10.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-21, 2]}, {11.5, -10.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-21, 2]}, {12.5, -10.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-21, 2]}, {13.5, -10.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-21, 2]}, {14.5, -10.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-23, 2]}, {6.5, -11.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-23, 2]}, {7.5, -11.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-23, 2]}, {8.5, -11.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-23, 2]}, {9.5, -11.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-23, 2]}, {10.5, -11.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-23, 2]}, {11.5, -11.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-23, 2]}, {12.5, -11.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-23, 2]}, {13.5, -11.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-23, 2]}, {14.5, -11.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-25, 2]}, {6.5, -12.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-25, 2]}, {7.5, -12.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-25, 2]}, {8.5, -12.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-25, 2]}, {9.5, -12.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-25, 2]}, {10.5, -12.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-25, 2]}, {11.5, -12.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-25, 2]}, {12.5, -12.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-25, 2]}, {13.5, -12.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-25, 2]}, {14.5, -12.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-27, 2]}, {6.5, -13.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-27, 2]}, {7.5, -13.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-27, 2]}, {8.5, -13.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-27, 2]}, {9.5, -13.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-27, 2]}, {10.5, -13.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-27, 2]}, {11.5, -13.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-27, 2]}, {12.5, -13.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-27, 2]}, {13.5, -13.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-27, 2]}, {14.5, -13.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-29, 2]}, {7.5, -14.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-29, 2]}, {8.5, -14.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-29, 2]}, {9.5, -14.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-29, 2]}, {10.5, -14.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-29, 2]}, {11.5, -14.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-29, 2]}, {12.5, -14.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-29, 2]}, {13.5, -14.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-31, 2]}, {4.5, -15.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-31, 2]}, {5.5, -15.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-31, 2]}, {7.5, -15.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-31, 2]}, {8.5, -15.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-31, 2]}, {9.5, -15.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-31, 2]}, {10.5, -15.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-31, 2]}, {11.5, -15.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-31, 2]}, {12.5, -15.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-31, 2]}, {13.5, -15.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-31, 2]}, {15.5, -15.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-31, 2]}, {16.5, -15.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-33, 2]}, {3.5, -16.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-33, 2]}, {4.5, -16.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-33, 2]}, {5.5, -16.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-33, 2]}, {6.5, -16.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-33, 2]}, {7.5, -16.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-33, 2]}, {8.5, -16.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-33, 2]}, {9.5, -16.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-33, 2]}, {10.5, -16.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-33, 2]}, {11.5, -16.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-33, 2]}, {12.5, -16.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-33, 2]}, {13.5, -16.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-33, 2]}, {14.5, -16.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-33, 2]}, {15.5, -16.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-33, 2]}, {16.5, -16.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-33, 2]}, {17.5, -16.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-35, 2]}, {2.5, -17.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-35, 2]}, {3.5, -17.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-35, 2]}, {4.5, -17.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-35, 2]}, {5.5, -17.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-35, 2]}, {6.5, -17.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-35, 2]}, {7.5, -17.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-35, 2]}, {8.5, -17.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-35, 2]}, {9.5, -17.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-35, 2]}, {10.5, -17.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-35, 2]}, {11.5, -17.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-35, 2]}, {12.5, -17.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-35, 2]}, {13.5, -17.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-35, 2]}, {14.5, -17.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-35, 2]}, {15.5, -17.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-35, 2]}, {16.5, -17.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-35, 2]}, {17.5, -17.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-35, 2]}, {18.5, -17.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-37, 2]}, {2.5, -18.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-37, 2]}, {3.5, -18.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-37, 2]}, {4.5, -18.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-37, 2]}, {5.5, -18.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-37, 2]}, {6.5, -18.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-37, 2]}, {7.5, -18.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-37, 2]}, {8.5, -18.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-37, 2]}, {9.5, -18.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-37, 2]}, {10.5, -18.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-37, 2]}, {11.5, -18.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-37, 2]}, {12.5, -18.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-37, 2]}, {13.5, -18.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-37, 2]}, {14.5, -18.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-37, 2]}, {15.5, -18.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-37, 2]}, {16.5, -18.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-37, 2]}, {17.5, -18.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-37, 2]}, {18.5, -18.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-39, 2]}, {2.5, -19.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-39, 2]}, {3.5, -19.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-39, 2]}, {4.5, -19.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-39, 2]}, {5.5, -19.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-39, 2]}, {6.5, -19.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-39, 2]}, {7.5, -19.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-39, 2]}, {8.5, -19.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-39, 2]}, {9.5, -19.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-39, 2]}, {10.5, -19.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-39, 2]}, {11.5, -19.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-39, 2]}, {12.5, -19.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-39, 2]}, {13.5, -19.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-39, 2]}, {14.5, -19.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-39, 2]}, {15.5, -19.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-39, 2]}, {16.5, -19.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-39, 2]}, {17.5, -19.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-39, 2]}, {18.5, -19.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-41, 2]}, {2.5, -20.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-41, 2]}, {3.5, -20.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-41, 2]}, {4.5, -20.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-41, 2]}, {5.5, -20.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-41, 2]}, {6.5, -20.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-41, 2]}, {7.5, -20.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-41, 2]}, {8.5, -20.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-41, 2]}, {9.5, -20.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-41, 2]}, {10.5, -20.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-41, 2]}, {11.5, -20.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-41, 2]}, {12.5, -20.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-41, 2]}, {13.5, -20.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-41, 2]}, {14.5, -20.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-41, 2]}, {15.5, -20.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-41, 2]}, {16.5, -20.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-41, 2]}, {17.5, -20.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-41, 2]}, {18.5, -20.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-43, 2]}, {2.5, -21.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-43, 2]}, {3.5, -21.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-43, 2]}, {4.5, -21.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-43, 2]}, {5.5, -21.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-43, 2]}, {6.5, -21.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-43, 2]}, {7.5, -21.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-43, 2]}, {8.5, -21.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-43, 2]}, {9.5, -21.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-43, 2]}, {10.5, -21.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-43, 2]}, {11.5, -21.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-43, 2]}, {12.5, -21.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-43, 2]}, {13.5, -21.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-43, 2]}, {14.5, -21.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-43, 2]}, {15.5, -21.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-43, 2]}, {16.5, -21.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-43, 2]}, {17.5, -21.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-43, 2]}, {18.5, -21.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-45, 2]}, {2.5, -22.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-45, 2]}, {3.5, -22.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-45, 2]}, {4.5, -22.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-45, 2]}, {5.5, -22.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-45, 2]}, {6.5, -22.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-45, 2]}, {7.5, -22.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-45, 2]}, {8.5, -22.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-45, 2]}, {9.5, -22.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-45, 2]}, {10.5, -22.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-45, 2]}, {11.5, -22.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-45, 2]}, {12.5, -22.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-45, 2]}, {13.5, -22.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-45, 2]}, {14.5, -22.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-45, 2]}, {15.5, -22.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-45, 2]}, {16.5, -22.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-45, 2]}, {17.5, -22.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-45, 2]}, {18.5, -22.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-47, 2]}, {3.5, -23.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-47, 2]}, {4.5, -23.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-47, 2]}, {5.5, -23.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-47, 2]}, {6.5, -23.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-47, 2]}, {7.5, -23.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-47, 2]}, {8.5, -23.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-47, 2]}, {10.5, -23.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-47, 2]}, {13.5, -23.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-47, 2]}, {14.5, -23.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-47, 2]}, {15.5, -23.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-47, 2]}, {16.5, -23.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-47, 2]}, {17.5, -23.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-49, 2]}, {10.5, -24.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-51, 2]}, {9.5, -25.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-51, 2]}, {10.5, -25.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-51, 2]}, {11.5, -25.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-53, 2]}, {9.5, -26.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-53, 2]}, {10.5, -26.5}]], 
    RectangleBox[
     NCache[{Rational[23, 2], Rational[-53, 2]}, {11.5, -26.5}]]}, {{}, 
    GraphicsComplexBox[CompressedData["
1:eJx1lk1qwzAQRkNXXWaRRRZZpMYIYYyRJdlpsuoZeoRC171iTtAztSV6iz5w
oQTxvvlmNPqxXj6+3j+fdrvd9+//3+/j7/nt8bveH7+HNr608b6Nl/t/fZG+
iqMnHr+j8p3FT4rvNvRV+iyeFA/vFR/kj578+DFf8s3ik+Lh5COefPjHDe74
SXwQD6oniqMnHj/yk2/YyEc/8RuVz/WQv2vjXvys+K6N6W9QfJS+F8ePek/K
14njH8XR99KTn/64n/QDvyQ9fFI8PIoH8V68E/f84dRDP0bp8cMfvyBOfaP0
UfpRevgg7n5N4u5fFuf8Ut8q/SI990uUnn7hx/qTr1M95w3ueN9X1MP+LuKc
v04cP9+HF/FrGzO/Wxszv1fpb9JfpceffjKfSXze4NSbpM/SJ+nhVbyIZ3H6
N0k/ig8b3Pexvw/+fvj7wn5mfdnvrG+QfpDe92UQ57zhx/mlHs438b7v0A8b
3OcZ/Sh9lB4exH1fDOL0i3qS9PSb9fR+YP+wH9hfpY1ZT/ZnFS/iWXwWp75J
nHq4v7L0+OGPXxGv4ov4Ku7z5PNWxYt4Fvd8mQ/zTeI+bz6PXk/8WO9ZnPrY
H1n6Kv0qPfNnP/v+9P1KPZwv3+/sz6P0e+l571Iv72HyEz+L22+WPkmfxf3+
9ft9kd7vefTUX8Wdz+/9WXr4szh65oMf/tRPfvq/Su/vJ/M5SE899f4DFlgT
5w==
     "], {{{}, {}, 
       {RGBColor[0.24720000000000014`, 0.24, 0.6], 
        LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
         18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
         35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
         52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
         69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 
         86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 
         102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115,
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
         129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142,
          143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 
         156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169,
          170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 
         183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 194, 195, 196,
          197, 198, 199, 200, 201, 202, 203, 204, 205, 206}]}}, {
       {RGBColor[0.24720000000000014`, 0.24, 0.6], 
        PointBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
         18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
         35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
         52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
         69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 
         86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 
         102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115,
          116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
         129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142,
          143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 
         156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169,
          170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 
         183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 194, 195, 196,
          197, 198, 199, 200, 201, 202, 203, 204, 205, 
         206}]}, {}, {}}}], {}}}]], "Output",
 CellLabel->"Out[33]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"showImageTour", "[", 
  RowBox[{"Style", "[", 
   RowBox[{"\"\<\[SpadeSuit]\>\"", ",", "50"}], "]"}], "]"}]], "Input",
 CellLabel->"In[34]:="],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0.7], EdgeForm[GrayLevel[0]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-23, 2]}, {14.5, -11.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-23, 2]}, {15.5, -11.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-25, 2]}, {14.5, -12.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-25, 2]}, {15.5, -12.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-27, 2]}, {13.5, -13.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-27, 2]}, {14.5, -13.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-27, 2]}, {15.5, -13.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-27, 2]}, {16.5, -13.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-29, 2]}, {13.5, -14.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-29, 2]}, {14.5, -14.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-29, 2]}, {15.5, -14.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-29, 2]}, {16.5, -14.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-29, 2]}, {17.5, -14.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-31, 2]}, {12.5, -15.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-31, 2]}, {13.5, -15.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-31, 2]}, {14.5, -15.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-31, 2]}, {15.5, -15.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-31, 2]}, {16.5, -15.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-31, 2]}, {17.5, -15.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-31, 2]}, {18.5, -15.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-33, 2]}, {11.5, -16.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-33, 2]}, {12.5, -16.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-33, 2]}, {13.5, -16.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-33, 2]}, {14.5, -16.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-33, 2]}, {15.5, -16.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-33, 2]}, {16.5, -16.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-33, 2]}, {17.5, -16.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-33, 2]}, {18.5, -16.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-35, 2]}, {10.5, -17.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-35, 2]}, {11.5, -17.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-35, 2]}, {12.5, -17.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-35, 2]}, {13.5, -17.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-35, 2]}, {14.5, -17.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-35, 2]}, {15.5, -17.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-35, 2]}, {16.5, -17.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-35, 2]}, {17.5, -17.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-35, 2]}, {18.5, -17.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-35, 2]}, {19.5, -17.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-37, 2]}, {9.5, -18.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-37, 2]}, {10.5, -18.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-37, 2]}, {11.5, -18.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-37, 2]}, {12.5, -18.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-37, 2]}, {13.5, -18.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-37, 2]}, {14.5, -18.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-37, 2]}, {15.5, -18.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-37, 2]}, {16.5, -18.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-37, 2]}, {17.5, -18.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-37, 2]}, {18.5, -18.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-37, 2]}, {19.5, -18.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-37, 2]}, {20.5, -18.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-39, 2]}, {8.5, -19.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-39, 2]}, {9.5, -19.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-39, 2]}, {10.5, -19.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-39, 2]}, {11.5, -19.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-39, 2]}, {12.5, -19.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-39, 2]}, {13.5, -19.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-39, 2]}, {14.5, -19.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-39, 2]}, {15.5, -19.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-39, 2]}, {16.5, -19.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-39, 2]}, {17.5, -19.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-39, 2]}, {18.5, -19.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-39, 2]}, {19.5, -19.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-39, 2]}, {20.5, -19.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-39, 2]}, {21.5, -19.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-41, 2]}, {7.5, -20.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-41, 2]}, {8.5, -20.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-41, 2]}, {9.5, -20.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-41, 2]}, {10.5, -20.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-41, 2]}, {11.5, -20.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-41, 2]}, {12.5, -20.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-41, 2]}, {13.5, -20.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-41, 2]}, {14.5, -20.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-41, 2]}, {15.5, -20.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-41, 2]}, {16.5, -20.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-41, 2]}, {17.5, -20.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-41, 2]}, {18.5, -20.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-41, 2]}, {19.5, -20.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-41, 2]}, {20.5, -20.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-41, 2]}, {21.5, -20.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-41, 2]}, {22.5, -20.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-43, 2]}, {6.5, -21.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-43, 2]}, {7.5, -21.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-43, 2]}, {8.5, -21.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-43, 2]}, {9.5, -21.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-43, 2]}, {10.5, -21.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-43, 2]}, {11.5, -21.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-43, 2]}, {12.5, -21.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-43, 2]}, {13.5, -21.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-43, 2]}, {14.5, -21.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-43, 2]}, {15.5, -21.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-43, 2]}, {16.5, -21.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-43, 2]}, {17.5, -21.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-43, 2]}, {18.5, -21.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-43, 2]}, {19.5, -21.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-43, 2]}, {20.5, -21.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-43, 2]}, {21.5, -21.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-43, 2]}, {22.5, -21.5}]], 
    RectangleBox[NCache[{Rational[47, 2], Rational[-43, 2]}, {23.5, -21.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-45, 2]}, {6.5, -22.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-45, 2]}, {7.5, -22.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-45, 2]}, {8.5, -22.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-45, 2]}, {9.5, -22.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-45, 2]}, {10.5, -22.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-45, 2]}, {11.5, -22.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-45, 2]}, {12.5, -22.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-45, 2]}, {13.5, -22.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-45, 2]}, {14.5, -22.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-45, 2]}, {15.5, -22.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-45, 2]}, {16.5, -22.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-45, 2]}, {17.5, -22.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-45, 2]}, {18.5, -22.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-45, 2]}, {19.5, -22.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-45, 2]}, {20.5, -22.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-45, 2]}, {21.5, -22.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-45, 2]}, {22.5, -22.5}]], 
    RectangleBox[NCache[{Rational[47, 2], Rational[-45, 2]}, {23.5, -22.5}]], 
    RectangleBox[NCache[{Rational[49, 2], Rational[-45, 2]}, {24.5, -22.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-47, 2]}, {5.5, -23.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-47, 2]}, {6.5, -23.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-47, 2]}, {7.5, -23.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-47, 2]}, {8.5, -23.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-47, 2]}, {9.5, -23.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-47, 2]}, {10.5, -23.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-47, 2]}, {11.5, -23.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-47, 2]}, {12.5, -23.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-47, 2]}, {13.5, -23.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-47, 2]}, {14.5, -23.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-47, 2]}, {15.5, -23.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-47, 2]}, {16.5, -23.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-47, 2]}, {17.5, -23.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-47, 2]}, {18.5, -23.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-47, 2]}, {19.5, -23.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-47, 2]}, {20.5, -23.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-47, 2]}, {21.5, -23.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-47, 2]}, {22.5, -23.5}]], 
    RectangleBox[NCache[{Rational[47, 2], Rational[-47, 2]}, {23.5, -23.5}]], 
    RectangleBox[NCache[{Rational[49, 2], Rational[-47, 2]}, {24.5, -23.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-49, 2]}, {4.5, -24.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-49, 2]}, {5.5, -24.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-49, 2]}, {6.5, -24.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-49, 2]}, {7.5, -24.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-49, 2]}, {8.5, -24.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-49, 2]}, {9.5, -24.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-49, 2]}, {10.5, -24.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-49, 2]}, {11.5, -24.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-49, 2]}, {12.5, -24.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-49, 2]}, {13.5, -24.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-49, 2]}, {14.5, -24.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-49, 2]}, {15.5, -24.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-49, 2]}, {16.5, -24.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-49, 2]}, {17.5, -24.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-49, 2]}, {18.5, -24.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-49, 2]}, {19.5, -24.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-49, 2]}, {20.5, -24.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-49, 2]}, {21.5, -24.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-49, 2]}, {22.5, -24.5}]], 
    RectangleBox[NCache[{Rational[47, 2], Rational[-49, 2]}, {23.5, -24.5}]], 
    RectangleBox[NCache[{Rational[49, 2], Rational[-49, 2]}, {24.5, -24.5}]], 
    RectangleBox[NCache[{Rational[51, 2], Rational[-49, 2]}, {25.5, -24.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-51, 2]}, {4.5, -25.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-51, 2]}, {5.5, -25.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-51, 2]}, {6.5, -25.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-51, 2]}, {7.5, -25.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-51, 2]}, {8.5, -25.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-51, 2]}, {9.5, -25.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-51, 2]}, {10.5, -25.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-51, 2]}, {11.5, -25.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-51, 2]}, {12.5, -25.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-51, 2]}, {13.5, -25.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-51, 2]}, {14.5, -25.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-51, 2]}, {15.5, -25.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-51, 2]}, {16.5, -25.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-51, 2]}, {17.5, -25.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-51, 2]}, {18.5, -25.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-51, 2]}, {19.5, -25.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-51, 2]}, {20.5, -25.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-51, 2]}, {21.5, -25.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-51, 2]}, {22.5, -25.5}]], 
    RectangleBox[NCache[{Rational[47, 2], Rational[-51, 2]}, {23.5, -25.5}]], 
    RectangleBox[NCache[{Rational[49, 2], Rational[-51, 2]}, {24.5, -25.5}]], 
    RectangleBox[NCache[{Rational[51, 2], Rational[-51, 2]}, {25.5, -25.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-53, 2]}, {4.5, -26.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-53, 2]}, {5.5, -26.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-53, 2]}, {6.5, -26.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-53, 2]}, {7.5, -26.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-53, 2]}, {8.5, -26.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-53, 2]}, {9.5, -26.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-53, 2]}, {10.5, -26.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-53, 2]}, {11.5, -26.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-53, 2]}, {12.5, -26.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-53, 2]}, {13.5, -26.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-53, 2]}, {14.5, -26.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-53, 2]}, {15.5, -26.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-53, 2]}, {16.5, -26.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-53, 2]}, {17.5, -26.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-53, 2]}, {18.5, -26.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-53, 2]}, {19.5, -26.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-53, 2]}, {20.5, -26.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-53, 2]}, {21.5, -26.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-53, 2]}, {22.5, -26.5}]], 
    RectangleBox[NCache[{Rational[47, 2], Rational[-53, 2]}, {23.5, -26.5}]], 
    RectangleBox[NCache[{Rational[49, 2], Rational[-53, 2]}, {24.5, -26.5}]], 
    RectangleBox[NCache[{Rational[51, 2], Rational[-53, 2]}, {25.5, -26.5}]], 
    RectangleBox[NCache[{Rational[53, 2], Rational[-53, 2]}, {26.5, -26.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-55, 2]}, {4.5, -27.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-55, 2]}, {5.5, -27.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-55, 2]}, {6.5, -27.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-55, 2]}, {7.5, -27.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-55, 2]}, {8.5, -27.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-55, 2]}, {9.5, -27.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-55, 2]}, {10.5, -27.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-55, 2]}, {11.5, -27.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-55, 2]}, {12.5, -27.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-55, 2]}, {13.5, -27.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-55, 2]}, {14.5, -27.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-55, 2]}, {15.5, -27.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-55, 2]}, {16.5, -27.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-55, 2]}, {17.5, -27.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-55, 2]}, {18.5, -27.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-55, 2]}, {19.5, -27.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-55, 2]}, {20.5, -27.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-55, 2]}, {21.5, -27.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-55, 2]}, {22.5, -27.5}]], 
    RectangleBox[NCache[{Rational[47, 2], Rational[-55, 2]}, {23.5, -27.5}]], 
    RectangleBox[NCache[{Rational[49, 2], Rational[-55, 2]}, {24.5, -27.5}]], 
    RectangleBox[NCache[{Rational[51, 2], Rational[-55, 2]}, {25.5, -27.5}]], 
    RectangleBox[NCache[{Rational[53, 2], Rational[-55, 2]}, {26.5, -27.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-57, 2]}, {3.5, -28.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-57, 2]}, {4.5, -28.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-57, 2]}, {5.5, -28.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-57, 2]}, {6.5, -28.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-57, 2]}, {7.5, -28.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-57, 2]}, {8.5, -28.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-57, 2]}, {9.5, -28.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-57, 2]}, {10.5, -28.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-57, 2]}, {11.5, -28.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-57, 2]}, {12.5, -28.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-57, 2]}, {13.5, -28.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-57, 2]}, {14.5, -28.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-57, 2]}, {15.5, -28.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-57, 2]}, {16.5, -28.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-57, 2]}, {17.5, -28.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-57, 2]}, {18.5, -28.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-57, 2]}, {19.5, -28.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-57, 2]}, {20.5, -28.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-57, 2]}, {21.5, -28.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-57, 2]}, {22.5, -28.5}]], 
    RectangleBox[NCache[{Rational[47, 2], Rational[-57, 2]}, {23.5, -28.5}]], 
    RectangleBox[NCache[{Rational[49, 2], Rational[-57, 2]}, {24.5, -28.5}]], 
    RectangleBox[NCache[{Rational[51, 2], Rational[-57, 2]}, {25.5, -28.5}]], 
    RectangleBox[NCache[{Rational[53, 2], Rational[-57, 2]}, {26.5, -28.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-59, 2]}, {4.5, -29.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-59, 2]}, {5.5, -29.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-59, 2]}, {6.5, -29.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-59, 2]}, {7.5, -29.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-59, 2]}, {8.5, -29.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-59, 2]}, {9.5, -29.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-59, 2]}, {10.5, -29.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-59, 2]}, {11.5, -29.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-59, 2]}, {12.5, -29.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-59, 2]}, {13.5, -29.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-59, 2]}, {14.5, -29.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-59, 2]}, {15.5, -29.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-59, 2]}, {16.5, -29.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-59, 2]}, {17.5, -29.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-59, 2]}, {18.5, -29.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-59, 2]}, {19.5, -29.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-59, 2]}, {20.5, -29.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-59, 2]}, {21.5, -29.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-59, 2]}, {22.5, -29.5}]], 
    RectangleBox[NCache[{Rational[47, 2], Rational[-59, 2]}, {23.5, -29.5}]], 
    RectangleBox[NCache[{Rational[49, 2], Rational[-59, 2]}, {24.5, -29.5}]], 
    RectangleBox[NCache[{Rational[51, 2], Rational[-59, 2]}, {25.5, -29.5}]], 
    RectangleBox[NCache[{Rational[53, 2], Rational[-59, 2]}, {26.5, -29.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-61, 2]}, {4.5, -30.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-61, 2]}, {5.5, -30.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-61, 2]}, {6.5, -30.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-61, 2]}, {7.5, -30.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-61, 2]}, {8.5, -30.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-61, 2]}, {9.5, -30.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-61, 2]}, {10.5, -30.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-61, 2]}, {11.5, -30.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-61, 2]}, {12.5, -30.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-61, 2]}, {13.5, -30.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-61, 2]}, {14.5, -30.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-61, 2]}, {15.5, -30.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-61, 2]}, {16.5, -30.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-61, 2]}, {17.5, -30.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-61, 2]}, {18.5, -30.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-61, 2]}, {19.5, -30.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-61, 2]}, {20.5, -30.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-61, 2]}, {21.5, -30.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-61, 2]}, {22.5, -30.5}]], 
    RectangleBox[NCache[{Rational[47, 2], Rational[-61, 2]}, {23.5, -30.5}]], 
    RectangleBox[NCache[{Rational[49, 2], Rational[-61, 2]}, {24.5, -30.5}]], 
    RectangleBox[NCache[{Rational[51, 2], Rational[-61, 2]}, {25.5, -30.5}]], 
    RectangleBox[NCache[{Rational[53, 2], Rational[-61, 2]}, {26.5, -30.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-63, 2]}, {4.5, -31.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-63, 2]}, {5.5, -31.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-63, 2]}, {6.5, -31.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-63, 2]}, {7.5, -31.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-63, 2]}, {8.5, -31.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-63, 2]}, {9.5, -31.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-63, 2]}, {10.5, -31.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-63, 2]}, {11.5, -31.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-63, 2]}, {12.5, -31.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-63, 2]}, {13.5, -31.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-63, 2]}, {14.5, -31.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-63, 2]}, {15.5, -31.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-63, 2]}, {16.5, -31.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-63, 2]}, {17.5, -31.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-63, 2]}, {18.5, -31.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-63, 2]}, {19.5, -31.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-63, 2]}, {20.5, -31.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-63, 2]}, {21.5, -31.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-63, 2]}, {22.5, -31.5}]], 
    RectangleBox[NCache[{Rational[47, 2], Rational[-63, 2]}, {23.5, -31.5}]], 
    RectangleBox[NCache[{Rational[49, 2], Rational[-63, 2]}, {24.5, -31.5}]], 
    RectangleBox[NCache[{Rational[51, 2], Rational[-63, 2]}, {25.5, -31.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-65, 2]}, {4.5, -32.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-65, 2]}, {5.5, -32.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-65, 2]}, {6.5, -32.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-65, 2]}, {7.5, -32.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-65, 2]}, {8.5, -32.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-65, 2]}, {9.5, -32.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-65, 2]}, {10.5, -32.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-65, 2]}, {11.5, -32.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-65, 2]}, {12.5, -32.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-65, 2]}, {13.5, -32.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-65, 2]}, {14.5, -32.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-65, 2]}, {15.5, -32.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-65, 2]}, {16.5, -32.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-65, 2]}, {17.5, -32.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-65, 2]}, {18.5, -32.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-65, 2]}, {19.5, -32.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-65, 2]}, {20.5, -32.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-65, 2]}, {21.5, -32.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-65, 2]}, {22.5, -32.5}]], 
    RectangleBox[NCache[{Rational[47, 2], Rational[-65, 2]}, {23.5, -32.5}]], 
    RectangleBox[NCache[{Rational[49, 2], Rational[-65, 2]}, {24.5, -32.5}]], 
    RectangleBox[NCache[{Rational[51, 2], Rational[-65, 2]}, {25.5, -32.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-67, 2]}, {5.5, -33.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-67, 2]}, {6.5, -33.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-67, 2]}, {7.5, -33.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-67, 2]}, {8.5, -33.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-67, 2]}, {9.5, -33.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-67, 2]}, {10.5, -33.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-67, 2]}, {11.5, -33.5}]], 
    RectangleBox[NCache[{Rational[25, 2], Rational[-67, 2]}, {12.5, -33.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-67, 2]}, {14.5, -33.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-67, 2]}, {15.5, -33.5}]], 
    RectangleBox[NCache[{Rational[35, 2], Rational[-67, 2]}, {17.5, -33.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-67, 2]}, {18.5, -33.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-67, 2]}, {19.5, -33.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-67, 2]}, {20.5, -33.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-67, 2]}, {21.5, -33.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-67, 2]}, {22.5, -33.5}]], 
    RectangleBox[NCache[{Rational[47, 2], Rational[-67, 2]}, {23.5, -33.5}]], 
    RectangleBox[NCache[{Rational[49, 2], Rational[-67, 2]}, {24.5, -33.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-69, 2]}, {6.5, -34.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-69, 2]}, {7.5, -34.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-69, 2]}, {8.5, -34.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-69, 2]}, {9.5, -34.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-69, 2]}, {10.5, -34.5}]], 
    RectangleBox[NCache[{Rational[23, 2], Rational[-69, 2]}, {11.5, -34.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-69, 2]}, {14.5, -34.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-69, 2]}, {15.5, -34.5}]], 
    RectangleBox[NCache[{Rational[37, 2], Rational[-69, 2]}, {18.5, -34.5}]], 
    RectangleBox[NCache[{Rational[39, 2], Rational[-69, 2]}, {19.5, -34.5}]], 
    RectangleBox[NCache[{Rational[41, 2], Rational[-69, 2]}, {20.5, -34.5}]], 
    RectangleBox[NCache[{Rational[43, 2], Rational[-69, 2]}, {21.5, -34.5}]], 
    RectangleBox[NCache[{Rational[45, 2], Rational[-69, 2]}, {22.5, -34.5}]], 
    RectangleBox[NCache[{Rational[47, 2], Rational[-69, 2]}, {23.5, -34.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-71, 2]}, {14.5, -35.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-71, 2]}, {15.5, -35.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-73, 2]}, {14.5, -36.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-73, 2]}, {15.5, -36.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-73, 2]}, {16.5, -36.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-75, 2]}, {13.5, -37.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-75, 2]}, {14.5, -37.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-75, 2]}, {15.5, -37.5}]], 
    RectangleBox[NCache[{Rational[33, 2], Rational[-75, 2]}, {16.5, -37.5}]], 
    RectangleBox[NCache[{Rational[27, 2], Rational[-77, 2]}, {13.5, -38.5}]], 
    RectangleBox[NCache[{Rational[29, 2], Rational[-77, 2]}, {14.5, -38.5}]], 
    RectangleBox[NCache[{Rational[31, 2], Rational[-77, 2]}, {15.5, -38.5}]], 
    RectangleBox[
     NCache[{Rational[33, 2], Rational[-77, 2]}, {16.5, -38.5}]]}, {{}, 
    GraphicsComplexBox[CompressedData["
1:eJx1mEuO2kAURZ2sIIMMesCAoAghhJBt/MHGH0jvIEuIlHG2gLKyXloUUaek
OuCetErn1Xv3faqA+vbrz8/fn7Ms+/spy/7/f/x9uT7+Dx+P/1/Degrrt7C+
hvUqrG9hvXms7/Ct+Hft3y3Yz2G9f20f9cAH8V7+zorfpHqzSryUv0LxTmF9
COs6rI9h3YZ1HtZdWBdhfQnrMqxH8TnlsT5V4NSzEa+1v5F/OPHxh76T9KOP
/NB3kn0pXojn4kf5x5562V8le/qHf/pLPvSffJkP6sH8tAvc++2/EUcfemrZ
t7Kn3sSjH+ihX530Xhb4II6/XvHOYd2LX8QH8VF8Emfegp44j+TDmv231D6z
/ZzaR3+97M+yh0/io/gg7nr14p0483CRPflcxAfxUXwSJ59WHD3k37y2f7oP
bE/9K9kzv3PKo1647y/fb77/fD+exAvxo/hefBvWB3Hu56M4/rnPc9mXsuc8
E4/zjh76T770n3rQb+pF/6oF7v327/jWZ/25+EH7d/J/kP1e9lvZux/4I779
oScXJ1/3258Xpeztz58n+C9kf5I9/WA+2F/KnnpznpjfdoHX4vSP80d/Oc+t
eCOOv072+D+Ld+K+z7AnXituvcSvZQ93PO4H9PTinfhZvBVvxK3HeulHJXv6
Sf/YX8qe/Y3sK9mX4vgvZH+Svb8vNLKnHuijfugZxCdxf57eUvun75NzyuN9
D6ef6KV/5EO/OG/Um/NJ/twH1If7gvO4X+Deb/+Ob33WP4qTfyGOf/YTH//o
Iz760cfnDfr5PeLfE9xP+GO+iMe8oId5QS/zQj7MC/kyL/RzEmceSnH8s5/4
+Ecf8dGPPvJDP/Ugv+0C9377d3zrs359v3n6fqTvQ7aPvBTHP/GIjx70oRf9
5EN+5Ev+1IP6UK9NWDNP67CuxZlHfs8yr/hjnonHvKOH83BY4N5v/45fi6N/
J45/9hMf/9ST+NR7FJ9THvuNv6vs6e9e9ujze8Qojh7yQy/5k88mrMmX9xP6
Tz/9HuH7w/eL7x/fT76/fL+535Psr7KnXsz/D/H31N8dHvzdb6l95MR/T+2j
/+K1v2ifv7a3v7v0Rj1wz4vm6Wl+Jtlz/ukH559+cf7pJ/2n3/R/s8C93/4d
fxL3exsc/+wnPv6ZT+LzHsj8Mc+17D3/Ph8+P6P4nPLYH/xdZU8/17JHH/54
3xR/8i9/mfkkTv1W4sQjP+o3yx6+Ft8scOrHfupLPPerFx/E0Ys/8iXeLbWP
9cLfnPKoF269xMc/8TcLHP3sP4v7fdfvv34fHsQncX8e6D37aV7mlMf84eSP
XvpFPpyXtwXu/Z4nv9/34tRjJY59J/vLxz9c2ipH
     "], {{{}, {}, 
       {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwl1WV7EAQUBeCN7u4ePbpGx+iuMbpHM2B055ROpVPBoBtbOgy6UbpTCYMG
3z1+eM/9BefcoIiosH6BAQEB0SLmxiI2cYhLPOKTgIQkIjFJSEoykpOClKQi
NWlISzrSk4GMZCIzWchKNrKTgyBykovc5CEv+chPMAUoSCEKU4SiFKM4JShJ
KUIoTRnKUo7yVKAilahMFUKpSjWqU4Oa1KI2dahLPerTgIY0ojFNaEoYzQin
OS1oSSta04a2tKM9HehIJzoTQRe60o3u9KAnvehNJH3oSz+i6M8ABjKIwQxh
KMMYzghGMorRjGEs4xjPBKL5gA+ZyCQmM4WpTGM6M5jJLGYzh4/4mLnMYz4L
WMgiFrOEpSxjOSv4hE9ZySo+43O+4EtWs4a1rGM9G9jIJjazha1sYzs7+Iqv
+YZv+Y7v+YEf2ckudrOHvexjPwc4yCF+4md+4VcOc4SjHOM4JzjJKU5zhrOc
4zwX+I3fucglLnOFq1zjOje4yS1uc4e73OM+D3jII/7gTx7zhKc84y/+5h/+
5TkveMkrXvOGt7zjPTHlDyQWsYlDXOIRnwQkJBGJSUJSkpGcFKQkFalJQ1rS
kZ4MZCQTmclCVrKRnRwEkZNc5CYPeclHfoIpQEEKUZgiFKUYxSlBSUoRQmnK
UJZylKcCFalEZaoQSlWqUZ0a1KQWtalDXepRnwY0pBGNaUJTwmhGOM1pQUta
0Zo2tKUd7elARzrRmQi60JVudKcHPelFbyLpQ19ixjuK/gxgIIMYzBCGMozh
jGAkoxjNGMYyjvFMCPz/D/wHlAWjfQ==
         "]]}}, {
       {RGBColor[0.24720000000000014`, 0.24, 0.6], PointBox[CompressedData["
1:eJwl1WV7EAQUBeCN7u4ePbpGx+iuMbpHM2B055ROpVPBoBtbOgy6UbpTCYMG
3z1+eM/9BefcoIiosH6BAQEB0SLmxiI2cYhLPOKTgIQkIjFJSEoykpOClKQi
NWlISzrSk4GMZCIzWchKNrKTgyBykovc5CEv+chPMAUoSCEKU4SiFKM4JShJ
KUIoTRnKUo7yVKAilahMFUKpSjWqU4Oa1KI2dahLPerTgIY0ojFNaEoYzQin
OS1oSSta04a2tKM9HehIJzoTQRe60o3u9KAnvehNJH3oSz+i6M8ABjKIwQxh
KMMYzghGMorRjGEs4xjPBKL5gA+ZyCQmM4WpTGM6M5jJLGYzh4/4mLnMYz4L
WMgiFrOEpSxjOSv4hE9ZySo+43O+4EtWs4a1rGM9G9jIJjazha1sYzs7+Iqv
+YZv+Y7v+YEf2ckudrOHvexjPwc4yCF+4md+4VcOc4SjHOM4JzjJKU5zhrOc
4zwX+I3fucglLnOFq1zjOje4yS1uc4e73OM+D3jII/7gTx7zhKc84y/+5h/+
5TkveMkrXvOGt7zjPTHlDyQWsYlDXOIRnwQkJBGJSUJSkpGcFKQkFalJQ1rS
kZ4MZCQTmclCVrKRnRwEkZNc5CYPeclHfoIpQEEKUZgiFKUYxSlBSUoRQmnK
UJZylKcCFalEZaoQSlWqUZ0a1KQWtalDXepRnwY0pBGNaUJTwmhGOM1pQUta
0Zo2tKUd7elARzrRmQi60JVudKcHPelFbyLpQ19ixjuK/gxgIIMYzBCGMozh
jGAkoxjNGMYyjvFMCPz/D/wHlAWjfQ==
         "]]}, {}, {}}}], {}}}]], "Output",
 CellLabel->"Out[34]="]
}, Open  ]],

Cell["And finally my rendition of Pacman...", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"showImageTour", "[", 
  RowBox[{"Graphics", "[", 
   RowBox[{
    RowBox[{"Disk", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], ",", "1", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Pi", "/", "8"}], ",", 
        RowBox[{
         RowBox[{"2", "\[Pi]"}], "-", 
         RowBox[{"\[Pi]", "/", "8"}]}]}], "}"}]}], "]"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "12"}]}], "]"}], "]"}]], "Input",
 CellLabel->"In[35]:="],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0.7], EdgeForm[GrayLevel[0]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-5, 2]}, {5.5, -2.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-5, 2]}, {6.5, -2.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-5, 2]}, {7.5, -2.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-7, 2]}, {3.5, -3.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-7, 2]}, {4.5, -3.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-7, 2]}, {5.5, -3.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-7, 2]}, {6.5, -3.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-7, 2]}, {7.5, -3.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-7, 2]}, {8.5, -3.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-7, 2]}, {9.5, -3.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-9, 2]}, {2.5, -4.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-9, 2]}, {3.5, -4.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-9, 2]}, {4.5, -4.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-9, 2]}, {5.5, -4.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-9, 2]}, {6.5, -4.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-9, 2]}, {7.5, -4.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-9, 2]}, {8.5, -4.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-9, 2]}, {9.5, -4.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-9, 2]}, {10.5, -4.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-11, 2]}, {2.5, -5.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-11, 2]}, {3.5, -5.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-11, 2]}, {4.5, -5.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-11, 2]}, {5.5, -5.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-11, 2]}, {6.5, -5.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-11, 2]}, {7.5, -5.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-11, 2]}, {8.5, -5.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-11, 2]}, {9.5, -5.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-11, 2]}, {10.5, -5.5}]], 
    RectangleBox[NCache[{Rational[3, 2], Rational[-13, 2]}, {1.5, -6.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-13, 2]}, {2.5, -6.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-13, 2]}, {3.5, -6.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-13, 2]}, {4.5, -6.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-13, 2]}, {5.5, -6.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-13, 2]}, {6.5, -6.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-13, 2]}, {7.5, -6.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-13, 2]}, {8.5, -6.5}]], 
    RectangleBox[NCache[{Rational[3, 2], Rational[-15, 2]}, {1.5, -7.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-15, 2]}, {2.5, -7.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-15, 2]}, {3.5, -7.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-15, 2]}, {4.5, -7.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-15, 2]}, {5.5, -7.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-15, 2]}, {6.5, -7.5}]], 
    RectangleBox[NCache[{Rational[3, 2], Rational[-17, 2]}, {1.5, -8.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-17, 2]}, {2.5, -8.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-17, 2]}, {3.5, -8.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-17, 2]}, {4.5, -8.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-17, 2]}, {5.5, -8.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-17, 2]}, {6.5, -8.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-17, 2]}, {7.5, -8.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-17, 2]}, {8.5, -8.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-19, 2]}, {2.5, -9.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-19, 2]}, {3.5, -9.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-19, 2]}, {4.5, -9.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-19, 2]}, {5.5, -9.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-19, 2]}, {6.5, -9.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-19, 2]}, {7.5, -9.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-19, 2]}, {8.5, -9.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-19, 2]}, {9.5, -9.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-19, 2]}, {10.5, -9.5}]], 
    RectangleBox[NCache[{Rational[5, 2], Rational[-21, 2]}, {2.5, -10.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-21, 2]}, {3.5, -10.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-21, 2]}, {4.5, -10.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-21, 2]}, {5.5, -10.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-21, 2]}, {6.5, -10.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-21, 2]}, {7.5, -10.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-21, 2]}, {8.5, -10.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-21, 2]}, {9.5, -10.5}]], 
    RectangleBox[NCache[{Rational[21, 2], Rational[-21, 2]}, {10.5, -10.5}]], 
    RectangleBox[NCache[{Rational[7, 2], Rational[-23, 2]}, {3.5, -11.5}]], 
    RectangleBox[NCache[{Rational[9, 2], Rational[-23, 2]}, {4.5, -11.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-23, 2]}, {5.5, -11.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-23, 2]}, {6.5, -11.5}]], 
    RectangleBox[NCache[{Rational[15, 2], Rational[-23, 2]}, {7.5, -11.5}]], 
    RectangleBox[NCache[{Rational[17, 2], Rational[-23, 2]}, {8.5, -11.5}]], 
    RectangleBox[NCache[{Rational[19, 2], Rational[-23, 2]}, {9.5, -11.5}]], 
    RectangleBox[NCache[{Rational[11, 2], Rational[-25, 2]}, {5.5, -12.5}]], 
    RectangleBox[NCache[{Rational[13, 2], Rational[-25, 2]}, {6.5, -12.5}]], 
    RectangleBox[
     NCache[{Rational[15, 2], Rational[-25, 2]}, {7.5, -12.5}]]}, {{}, 
    GraphicsComplexBox[CompressedData["
1:eJx1kzEKAyEQRSXVlhYWFhZGFskxcoIUOUIgda64R0vCzmseuLDI8N/MfEe9
vj7P9yWl9Pj9/zW++7n041y3iPeIS8Qz4hbxLeIqvovfF/pQPv1zxE16lR94
/FBvLPrhFz/4m4t812/S8UN+Uf1NfBGfpcM36fhP4rN46jMf/NUFn8TTfxPP
eXj+WXwRTz36069LZ17eL/Wa+Codnvx9oXseTbrPm/szIuZ+zIU+1R++i6/S
6Ud+WfDc3yye+VOP99zE+31X6cyPfswbPz4P34cmvUv3e8c//dkv/shnP/Zb
xHu/4/gCAdtfUA==
     "], {{{}, {}, 
       {RGBColor[0.24720000000000014`, 0.24, 0.6], 
        LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
         18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
         35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
         52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
         69, 70, 71, 72, 73, 74, 75, 76, 77, 78}]}}, {
       {RGBColor[0.24720000000000014`, 0.24, 0.6], 
        PointBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
         18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
         35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
         52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
         69, 70, 71, 72, 73, 74, 75, 76, 77, 
         78}]}, {}, {}}}], {}}}]], "Output",
 CellLabel->"Out[35]="]
}, Open  ]],

Cell["\<\
Feel free to share any interesting disoveries in the comments section.\
\>", "Text"]
}, Open  ]]
},
WindowSize->{695, 752},
WindowMargins->{{Automatic, 304}, {-72, Automatic}},
FrontEndVersion->"11.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (July 2, \
2016)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    StyleData[StyleDefinitions -> "StyleMenuClear.nb"]], 
   Cell[
    StyleData["Notebook"], PageWidth -> 550, CellLabelAutoDelete -> False, 
    DefaultNewCellStyle -> "Text", 
    AutoStyleOptions -> {
     "FunctionLocalVariableStyle" -> None, "LocalVariableStyle" -> None, 
      "PatternVariableStyle" -> {FontSlant -> "Italic"}, 
      "StringStyle" -> {
       FontColor -> GrayLevel[0], ShowAutoStyles -> False, ShowSyntaxStyles -> 
        False, AutoNumberFormatting -> False}, "UndefinedSymbolStyle" -> 
      None}, GraphicsBoxOptions -> {ImageSize -> {446, Automatic}}], 
   Cell[
    StyleData["Title"], CellMargins -> {{59, Inherited}, {1, 60}}, 
    MenuCommandKey -> "1", FontSize -> 14, FontColor -> 
    RGBColor[0.8, 0, 0], $CellContext`MenuPosition -> 1000], 
   Cell[
    StyleData["Text"], CellMargins -> {{60, 10}, {8, 7}}, 
    LineSpacing -> {1, 1.5}, MenuCommandKey -> "7", FontFamily -> "Helvetica",
     FontSize -> 12, $CellContext`ReturnCreatesNewCell -> 
    True, $CellContext`MenuPosition -> 7000], 
   Cell[
    StyleData["Date", StyleDefinitions -> StyleData["Text"]], 
    CellMargins -> {{60, 10}, {1, 0}}, MenuCommandKey -> "2", FontFamily -> 
    "Helvetica", FontSize -> 11, $CellContext`MenuPosition -> 2000], 
   Cell[
    StyleData["Author", StyleDefinitions -> StyleData["Text"]], 
    CellMargins -> {{60, 10}, {5, 1}}, MenuCommandKey -> "3", FontFamily -> 
    "Helvetica", FontSize -> 12, $CellContext`MenuPosition -> 3000], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["TextAnnotation"], CellFrame -> 1, CellFrameColor -> 
       RGBColor[0.8, 0, 0], AutoSpacing -> False, LineIndent -> Automatic, 
       FontSize -> 11, FontWeight -> "Plain", FontColor -> 
       RGBColor[0.4, 0.2, 0.2], Background -> GrayLevel[0.999]], 
      Cell[
       StyleData["TextAnnotation", "Printout"]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["TextAnnotationButton"], Editable -> False, FontFamily -> 
       "Verdana", FontSize -> 9, 
       ButtonBoxOptions -> {
        Active -> True, Appearance -> "DialogBox", 
         ButtonFunction :> (Needs["BlogTools`"]; 
          BlogTools`BlogGenerateAnnotationDialog[]), ButtonMargins -> 1, 
         Evaluator -> Automatic, Method -> "Queued"}], 
      Cell[
       StyleData["TextAnnotationButton", "Printout"]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["TextAnnotator"], Editable -> False, FontFamily -> "Verdana",
        FontSize -> 9], 
      Cell[
       StyleData["TextAnnotator", "Printout"]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["TextAnnotationRemoveButton"], Editable -> False, FontFamily -> 
       "Verdana", FontSize -> 9, 
       ButtonBoxOptions -> {
        Active -> True, Appearance -> "DialogBox", 
         ButtonFunction :> (Needs["BlogTools`"]; 
          BlogTools`BlogAnnotationRemove[
           BlogTools`BlogCalledFromFrameLabel -> True]), ButtonMargins -> 1, 
         Evaluator -> Automatic, Method -> "Queued"}], 
      Cell[
       StyleData["TextAnnotationRemoveButton", "Printout"]]}, Closed]], 
   Cell[
    StyleData["Hyperlink"], FontColor -> RGBColor[0.8, 0, 0]], 
   Cell[
    StyleData["FunctionLink", StyleDefinitions -> StyleData["Hyperlink"]], 
    FontFamily -> "Courier", FontSize -> 13, FontColor -> RGBColor[0.8, 0, 0],
     ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
         NotebookLocate[#2]}]& ), Evaluator -> None, Method -> 
      "Queued"}, $CellContext`MenuPosition -> 10000], 
   Cell[
    StyleData["InlineCode"], FontFamily -> "Courier", FontSize -> 
    13, $CellContext`MenuPosition -> 10000], 
   Cell[
    StyleData["Input"], CellMargins -> {{60, 10}, {5, 10}}, MenuCommandKey -> 
    "9", $CellContext`MenuPosition -> 9000], 
   Cell[
    StyleData["Output"], CellMargins -> {{60, 10}, {10, 5}}], 
   Cell[
    StyleData["Program"], CellFrame -> False, 
    CellMargins -> {{60, 4}, {8, 8}}, MenuCommandKey -> 
    "8", $CellContext`MenuPosition -> 8000], 
   Cell[
    StyleData["Picture"], CellMargins -> {{60, Inherited}, {8, 8}}, 
    MenuCommandKey -> "6", 
    GraphicsBoxOptions -> {
     ImageSize -> {446, Automatic}}, $CellContext`MenuPosition -> 6000], 
   Cell[
    StyleData["ImageGraphics"], 
    GraphicsBoxOptions -> {ImageSize -> {446, Automatic}}]}, Visible -> False,
   FrontEndVersion -> 
  "11.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (July 2, 2016)", 
  StyleDefinitions -> "Default.nb"],
PrivateNotebookOptions -> {"NotebookAuthor" -> ""},
$CellContext`CreateCellID -> True
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 88, 1, 78, "Title",
 CellID->348904812],
Cell[670, 25, 49, 1, 13, "Date",
 CellID->1412818974],
Cell[722, 28, 107, 3, 19, "Author",
 CellID->521811139],
Cell[832, 33, 1508, 28, 202, "Text"],
Cell[2343, 63, 51, 0, 28, "Text"],
Cell[2397, 65, 862, 20, 106, "Text"],
Cell[3262, 87, 769, 23, 144, "Input"],
Cell[4034, 112, 206, 4, 43, "Text"],
Cell[CellGroupData[{
Cell[4265, 120, 216, 6, 32, "Input"],
Cell[4484, 128, 32547, 573, 458, "Output"]
}, Open  ]],
Cell[37046, 704, 63, 0, 28, "Text"],
Cell[CellGroupData[{
Cell[37134, 708, 111, 2, 28, "Input"],
Cell[37248, 712, 10125, 323, 386, "Output"]
}, Open  ]],
Cell[47388, 1038, 68, 0, 28, "Text"],
Cell[CellGroupData[{
Cell[47481, 1042, 1077, 32, 131, "Input"],
Cell[48561, 1076, 5820, 82, 460, "Output"]
}, Open  ]],
Cell[54396, 1161, 2226, 45, 304, "Text"],
Cell[56625, 1208, 541, 17, 63, "Input"],
Cell[57169, 1227, 206, 5, 46, "Input"],
Cell[57378, 1234, 151, 3, 43, "Text"],
Cell[57532, 1239, 971, 27, 114, "Input"],
Cell[58506, 1268, 681, 12, 86, "Text"],
Cell[59190, 1282, 212, 5, 46, "Input"],
Cell[59405, 1289, 557, 17, 63, "Input"],
Cell[59965, 1308, 61, 0, 28, "Text"],
Cell[CellGroupData[{
Cell[60051, 1312, 142, 3, 28, "Input"],
Cell[60196, 1317, 159, 5, 28, "Output"]
}, Open  ]],
Cell[60370, 1325, 162, 3, 43, "Text"],
Cell[CellGroupData[{
Cell[60557, 1332, 169, 4, 28, "Input"],
Cell[60729, 1338, 5736, 81, 413, "Output"]
}, Open  ]],
Cell[66480, 1422, 74, 0, 28, "Text"],
Cell[CellGroupData[{
Cell[66579, 1426, 169, 4, 28, "Input"],
Cell[66751, 1432, 42074, 557, 507, "Output"]
}, Open  ]],
Cell[108840, 1992, 169, 3, 43, "Text"],
Cell[CellGroupData[{
Cell[109034, 1999, 155, 4, 28, "Input"],
Cell[109192, 2005, 12625, 169, 413, "Output"]
}, Open  ]],
Cell[121832, 2177, 39, 0, 28, "Text"],
Cell[CellGroupData[{
Cell[121896, 2181, 155, 4, 28, "Input"],
Cell[122054, 2187, 12717, 169, 438, "Output"]
}, Open  ]],
Cell[134786, 2359, 159, 3, 28, "Text"],
Cell[CellGroupData[{
Cell[134970, 2366, 165, 4, 28, "Input"],
Cell[135138, 2372, 19496, 258, 536, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[154671, 2635, 166, 4, 28, "Input"],
Cell[154840, 2641, 33826, 447, 531, "Output"]
}, Open  ]],
Cell[188681, 3091, 53, 0, 28, "Text"],
Cell[CellGroupData[{
Cell[188759, 3095, 490, 15, 46, "Input"],
Cell[189252, 3112, 7348, 103, 503, "Output"]
}, Open  ]],
Cell[196615, 3218, 94, 2, 28, "Text"]
}, Open  ]]
}
]
*)

